/*
Copyright (c) 2002,2003, Christian Nowak <chnowak@web.de>
All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are 
permitted provided that the following conditions are met:

- Redistributions of source code must retain the above copyright notice, this list of 
  conditions and the following disclaimer. 
- Redistributions in binary form must reproduce the above copyright notice, this list 
  of conditions and the following disclaimer in the documentation and/or other 
  materials provided with the distribution. 
- The names of the contributors may not be used to endorse or promote products derived 
  from this software without specific prior written permission. 

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, 
STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#include "defines.h"

/* Convert an Amiga freqency value (0..4095) to a semitone offset */
u8 semitonetab[4096] =
  {
    0,    /* freqval=000 */
    143,  /* freqval=001 */
    131,  /* freqval=002 */
    124,  /* freqval=003 */
    119,  /* freqval=004 */
    116,  /* freqval=005 */
    112,  /* freqval=006 */
    110,  /* freqval=007 */
    107,  /* freqval=008 */
    105,  /* freqval=009 */
    104,  /* freqval=00a */
    102,  /* freqval=00b */
    100,  /* freqval=00c */
    99,   /* freqval=00d */
    98,   /* freqval=00e */
    97,   /* freqval=00f */
    95,   /* freqval=010 */
    94,   /* freqval=011 */
    93,   /* freqval=012 */
    93,   /* freqval=013 */
    92,   /* freqval=014 */
    91,   /* freqval=015 */
    90,   /* freqval=016 */
    89,   /* freqval=017 */
    88,   /* freqval=018 */
    88,   /* freqval=019 */
    87,   /* freqval=01a */
    86,   /* freqval=01b */
    86,   /* freqval=01c */
    85,   /* freqval=01d */
    85,   /* freqval=01e */
    84,   /* freqval=01f */
    83,   /* freqval=020 */
    83,   /* freqval=021 */
    82,   /* freqval=022 */
    82,   /* freqval=023 */
    81,   /* freqval=024 */
    81,   /* freqval=025 */
    81,   /* freqval=026 */
    80,   /* freqval=027 */
    80,   /* freqval=028 */
    79,   /* freqval=029 */
    79,   /* freqval=02a */
    78,   /* freqval=02b */
    78,   /* freqval=02c */
    78,   /* freqval=02d */
    77,   /* freqval=02e */
    77,   /* freqval=02f */
    76,   /* freqval=030 */
    76,   /* freqval=031 */
    76,   /* freqval=032 */
    75,   /* freqval=033 */
    75,   /* freqval=034 */
    75,   /* freqval=035 */
    74,   /* freqval=036 */
    74,   /* freqval=037 */
    74,   /* freqval=038 */
    74,   /* freqval=039 */
    73,   /* freqval=03a */
    73,   /* freqval=03b */
    73,   /* freqval=03c */
    72,   /* freqval=03d */
    72,   /* freqval=03e */
    72,   /* freqval=03f */
    71,   /* freqval=040 */
    71,   /* freqval=041 */
    71,   /* freqval=042 */
    71,   /* freqval=043 */
    70,   /* freqval=044 */
    70,   /* freqval=045 */
    70,   /* freqval=046 */
    70,   /* freqval=047 */
    69,   /* freqval=048 */
    69,   /* freqval=049 */
    69,   /* freqval=04a */
    69,   /* freqval=04b */
    69,   /* freqval=04c */
    68,   /* freqval=04d */
    68,   /* freqval=04e */
    68,   /* freqval=04f */
    68,   /* freqval=050 */
    67,   /* freqval=051 */
    67,   /* freqval=052 */
    67,   /* freqval=053 */
    67,   /* freqval=054 */
    67,   /* freqval=055 */
    66,   /* freqval=056 */
    66,   /* freqval=057 */
    66,   /* freqval=058 */
    66,   /* freqval=059 */
    66,   /* freqval=05a */
    65,   /* freqval=05b */
    65,   /* freqval=05c */
    65,   /* freqval=05d */
    65,   /* freqval=05e */
    65,   /* freqval=05f */
    64,   /* freqval=060 */
    64,   /* freqval=061 */
    64,   /* freqval=062 */
    64,   /* freqval=063 */
    64,   /* freqval=064 */
    64,   /* freqval=065 */
    63,   /* freqval=066 */
    63,   /* freqval=067 */
    63,   /* freqval=068 */
    63,   /* freqval=069 */
    63,   /* freqval=06a */
    63,   /* freqval=06b */
    62,   /* freqval=06c */
    62,   /* freqval=06d */
    62,   /* freqval=06e */
    62,   /* freqval=06f */
    62,   /* freqval=070 */
    62,   /* freqval=071 */
    62,   /* freqval=072 */
    61,   /* freqval=073 */
    61,   /* freqval=074 */
    61,   /* freqval=075 */
    61,   /* freqval=076 */
    61,   /* freqval=077 */
    61,   /* freqval=078 */
    60,   /* freqval=079 */
    60,   /* freqval=07a */
    60,   /* freqval=07b */
    60,   /* freqval=07c */
    60,   /* freqval=07d */
    60,   /* freqval=07e */
    60,   /* freqval=07f */
    59,   /* freqval=080 */
    59,   /* freqval=081 */
    59,   /* freqval=082 */
    59,   /* freqval=083 */
    59,   /* freqval=084 */
    59,   /* freqval=085 */
    59,   /* freqval=086 */
    59,   /* freqval=087 */
    58,   /* freqval=088 */
    58,   /* freqval=089 */
    58,   /* freqval=08a */
    58,   /* freqval=08b */
    58,   /* freqval=08c */
    58,   /* freqval=08d */
    58,   /* freqval=08e */
    58,   /* freqval=08f */
    57,   /* freqval=090 */
    57,   /* freqval=091 */
    57,   /* freqval=092 */
    57,   /* freqval=093 */
    57,   /* freqval=094 */
    57,   /* freqval=095 */
    57,   /* freqval=096 */
    57,   /* freqval=097 */
    57,   /* freqval=098 */
    56,   /* freqval=099 */
    56,   /* freqval=09a */
    56,   /* freqval=09b */
    56,   /* freqval=09c */
    56,   /* freqval=09d */
    56,   /* freqval=09e */
    56,   /* freqval=09f */
    56,   /* freqval=0a0 */
    56,   /* freqval=0a1 */
    55,   /* freqval=0a2 */
    55,   /* freqval=0a3 */
    55,   /* freqval=0a4 */
    55,   /* freqval=0a5 */
    55,   /* freqval=0a6 */
    55,   /* freqval=0a7 */
    55,   /* freqval=0a8 */
    55,   /* freqval=0a9 */
    55,   /* freqval=0aa */
    54,   /* freqval=0ab */
    54,   /* freqval=0ac */
    54,   /* freqval=0ad */
    54,   /* freqval=0ae */
    54,   /* freqval=0af */
    54,   /* freqval=0b0 */
    54,   /* freqval=0b1 */
    54,   /* freqval=0b2 */
    54,   /* freqval=0b3 */
    54,   /* freqval=0b4 */
    53,   /* freqval=0b5 */
    53,   /* freqval=0b6 */
    53,   /* freqval=0b7 */
    53,   /* freqval=0b8 */
    53,   /* freqval=0b9 */
    53,   /* freqval=0ba */
    53,   /* freqval=0bb */
    53,   /* freqval=0bc */
    53,   /* freqval=0bd */
    53,   /* freqval=0be */
    53,   /* freqval=0bf */
    52,   /* freqval=0c0 */
    52,   /* freqval=0c1 */
    52,   /* freqval=0c2 */
    52,   /* freqval=0c3 */
    52,   /* freqval=0c4 */
    52,   /* freqval=0c5 */
    52,   /* freqval=0c6 */
    52,   /* freqval=0c7 */
    52,   /* freqval=0c8 */
    52,   /* freqval=0c9 */
    52,   /* freqval=0ca */
    52,   /* freqval=0cb */
    51,   /* freqval=0cc */
    51,   /* freqval=0cd */
    51,   /* freqval=0ce */
    51,   /* freqval=0cf */
    51,   /* freqval=0d0 */
    51,   /* freqval=0d1 */
    51,   /* freqval=0d2 */
    51,   /* freqval=0d3 */
    51,   /* freqval=0d4 */
    51,   /* freqval=0d5 */
    51,   /* freqval=0d6 */
    51,   /* freqval=0d7 */
    50,   /* freqval=0d8 */
    50,   /* freqval=0d9 */
    50,   /* freqval=0da */
    50,   /* freqval=0db */
    50,   /* freqval=0dc */
    50,   /* freqval=0dd */
    50,   /* freqval=0de */
    50,   /* freqval=0df */
    50,   /* freqval=0e0 */
    50,   /* freqval=0e1 */
    50,   /* freqval=0e2 */
    50,   /* freqval=0e3 */
    50,   /* freqval=0e4 */
    49,   /* freqval=0e5 */
    49,   /* freqval=0e6 */
    49,   /* freqval=0e7 */
    49,   /* freqval=0e8 */
    49,   /* freqval=0e9 */
    49,   /* freqval=0ea */
    49,   /* freqval=0eb */
    49,   /* freqval=0ec */
    49,   /* freqval=0ed */
    49,   /* freqval=0ee */
    49,   /* freqval=0ef */
    49,   /* freqval=0f0 */
    49,   /* freqval=0f1 */
    48,   /* freqval=0f2 */
    48,   /* freqval=0f3 */
    48,   /* freqval=0f4 */
    48,   /* freqval=0f5 */
    48,   /* freqval=0f6 */
    48,   /* freqval=0f7 */
    48,   /* freqval=0f8 */
    48,   /* freqval=0f9 */
    48,   /* freqval=0fa */
    48,   /* freqval=0fb */
    48,   /* freqval=0fc */
    48,   /* freqval=0fd */
    48,   /* freqval=0fe */
    48,   /* freqval=0ff */
    47,   /* freqval=100 */
    47,   /* freqval=101 */
    47,   /* freqval=102 */
    47,   /* freqval=103 */
    47,   /* freqval=104 */
    47,   /* freqval=105 */
    47,   /* freqval=106 */
    47,   /* freqval=107 */
    47,   /* freqval=108 */
    47,   /* freqval=109 */
    47,   /* freqval=10a */
    47,   /* freqval=10b */
    47,   /* freqval=10c */
    47,   /* freqval=10d */
    47,   /* freqval=10e */
    47,   /* freqval=10f */
    46,   /* freqval=110 */
    46,   /* freqval=111 */
    46,   /* freqval=112 */
    46,   /* freqval=113 */
    46,   /* freqval=114 */
    46,   /* freqval=115 */
    46,   /* freqval=116 */
    46,   /* freqval=117 */
    46,   /* freqval=118 */
    46,   /* freqval=119 */
    46,   /* freqval=11a */
    46,   /* freqval=11b */
    46,   /* freqval=11c */
    46,   /* freqval=11d */
    46,   /* freqval=11e */
    46,   /* freqval=11f */
    45,   /* freqval=120 */
    45,   /* freqval=121 */
    45,   /* freqval=122 */
    45,   /* freqval=123 */
    45,   /* freqval=124 */
    45,   /* freqval=125 */
    45,   /* freqval=126 */
    45,   /* freqval=127 */
    45,   /* freqval=128 */
    45,   /* freqval=129 */
    45,   /* freqval=12a */
    45,   /* freqval=12b */
    45,   /* freqval=12c */
    45,   /* freqval=12d */
    45,   /* freqval=12e */
    45,   /* freqval=12f */
    45,   /* freqval=130 */
    44,   /* freqval=131 */
    44,   /* freqval=132 */
    44,   /* freqval=133 */
    44,   /* freqval=134 */
    44,   /* freqval=135 */
    44,   /* freqval=136 */
    44,   /* freqval=137 */
    44,   /* freqval=138 */
    44,   /* freqval=139 */
    44,   /* freqval=13a */
    44,   /* freqval=13b */
    44,   /* freqval=13c */
    44,   /* freqval=13d */
    44,   /* freqval=13e */
    44,   /* freqval=13f */
    44,   /* freqval=140 */
    44,   /* freqval=141 */
    44,   /* freqval=142 */
    43,   /* freqval=143 */
    43,   /* freqval=144 */
    43,   /* freqval=145 */
    43,   /* freqval=146 */
    43,   /* freqval=147 */
    43,   /* freqval=148 */
    43,   /* freqval=149 */
    43,   /* freqval=14a */
    43,   /* freqval=14b */
    43,   /* freqval=14c */
    43,   /* freqval=14d */
    43,   /* freqval=14e */
    43,   /* freqval=14f */
    43,   /* freqval=150 */
    43,   /* freqval=151 */
    43,   /* freqval=152 */
    43,   /* freqval=153 */
    43,   /* freqval=154 */
    43,   /* freqval=155 */
    42,   /* freqval=156 */
    42,   /* freqval=157 */
    42,   /* freqval=158 */
    42,   /* freqval=159 */
    42,   /* freqval=15a */
    42,   /* freqval=15b */
    42,   /* freqval=15c */
    42,   /* freqval=15d */
    42,   /* freqval=15e */
    42,   /* freqval=15f */
    42,   /* freqval=160 */
    42,   /* freqval=161 */
    42,   /* freqval=162 */
    42,   /* freqval=163 */
    42,   /* freqval=164 */
    42,   /* freqval=165 */
    42,   /* freqval=166 */
    42,   /* freqval=167 */
    42,   /* freqval=168 */
    42,   /* freqval=169 */
    41,   /* freqval=16a */
    41,   /* freqval=16b */
    41,   /* freqval=16c */
    41,   /* freqval=16d */
    41,   /* freqval=16e */
    41,   /* freqval=16f */
    41,   /* freqval=170 */
    41,   /* freqval=171 */
    41,   /* freqval=172 */
    41,   /* freqval=173 */
    41,   /* freqval=174 */
    41,   /* freqval=175 */
    41,   /* freqval=176 */
    41,   /* freqval=177 */
    41,   /* freqval=178 */
    41,   /* freqval=179 */
    41,   /* freqval=17a */
    41,   /* freqval=17b */
    41,   /* freqval=17c */
    41,   /* freqval=17d */
    41,   /* freqval=17e */
    41,   /* freqval=17f */
    40,   /* freqval=180 */
    40,   /* freqval=181 */
    40,   /* freqval=182 */
    40,   /* freqval=183 */
    40,   /* freqval=184 */
    40,   /* freqval=185 */
    40,   /* freqval=186 */
    40,   /* freqval=187 */
    40,   /* freqval=188 */
    40,   /* freqval=189 */
    40,   /* freqval=18a */
    40,   /* freqval=18b */
    40,   /* freqval=18c */
    40,   /* freqval=18d */
    40,   /* freqval=18e */
    40,   /* freqval=18f */
    40,   /* freqval=190 */
    40,   /* freqval=191 */
    40,   /* freqval=192 */
    40,   /* freqval=193 */
    40,   /* freqval=194 */
    40,   /* freqval=195 */
    40,   /* freqval=196 */
    39,   /* freqval=197 */
    39,   /* freqval=198 */
    39,   /* freqval=199 */
    39,   /* freqval=19a */
    39,   /* freqval=19b */
    39,   /* freqval=19c */
    39,   /* freqval=19d */
    39,   /* freqval=19e */
    39,   /* freqval=19f */
    39,   /* freqval=1a0 */
    39,   /* freqval=1a1 */
    39,   /* freqval=1a2 */
    39,   /* freqval=1a3 */
    39,   /* freqval=1a4 */
    39,   /* freqval=1a5 */
    39,   /* freqval=1a6 */
    39,   /* freqval=1a7 */
    39,   /* freqval=1a8 */
    39,   /* freqval=1a9 */
    39,   /* freqval=1aa */
    39,   /* freqval=1ab */
    39,   /* freqval=1ac */
    39,   /* freqval=1ad */
    39,   /* freqval=1ae */
    38,   /* freqval=1af */
    38,   /* freqval=1b0 */
    38,   /* freqval=1b1 */
    38,   /* freqval=1b2 */
    38,   /* freqval=1b3 */
    38,   /* freqval=1b4 */
    38,   /* freqval=1b5 */
    38,   /* freqval=1b6 */
    38,   /* freqval=1b7 */
    38,   /* freqval=1b8 */
    38,   /* freqval=1b9 */
    38,   /* freqval=1ba */
    38,   /* freqval=1bb */
    38,   /* freqval=1bc */
    38,   /* freqval=1bd */
    38,   /* freqval=1be */
    38,   /* freqval=1bf */
    38,   /* freqval=1c0 */
    38,   /* freqval=1c1 */
    38,   /* freqval=1c2 */
    38,   /* freqval=1c3 */
    38,   /* freqval=1c4 */
    38,   /* freqval=1c5 */
    38,   /* freqval=1c6 */
    38,   /* freqval=1c7 */
    38,   /* freqval=1c8 */
    37,   /* freqval=1c9 */
    37,   /* freqval=1ca */
    37,   /* freqval=1cb */
    37,   /* freqval=1cc */
    37,   /* freqval=1cd */
    37,   /* freqval=1ce */
    37,   /* freqval=1cf */
    37,   /* freqval=1d0 */
    37,   /* freqval=1d1 */
    37,   /* freqval=1d2 */
    37,   /* freqval=1d3 */
    37,   /* freqval=1d4 */
    37,   /* freqval=1d5 */
    37,   /* freqval=1d6 */
    37,   /* freqval=1d7 */
    37,   /* freqval=1d8 */
    37,   /* freqval=1d9 */
    37,   /* freqval=1da */
    37,   /* freqval=1db */
    37,   /* freqval=1dc */
    37,   /* freqval=1dd */
    37,   /* freqval=1de */
    37,   /* freqval=1df */
    37,   /* freqval=1e0 */
    37,   /* freqval=1e1 */
    37,   /* freqval=1e2 */
    37,   /* freqval=1e3 */
    36,   /* freqval=1e4 */
    36,   /* freqval=1e5 */
    36,   /* freqval=1e6 */
    36,   /* freqval=1e7 */
    36,   /* freqval=1e8 */
    36,   /* freqval=1e9 */
    36,   /* freqval=1ea */
    36,   /* freqval=1eb */
    36,   /* freqval=1ec */
    36,   /* freqval=1ed */
    36,   /* freqval=1ee */
    36,   /* freqval=1ef */
    36,   /* freqval=1f0 */
    36,   /* freqval=1f1 */
    36,   /* freqval=1f2 */
    36,   /* freqval=1f3 */
    36,   /* freqval=1f4 */
    36,   /* freqval=1f5 */
    36,   /* freqval=1f6 */
    36,   /* freqval=1f7 */
    36,   /* freqval=1f8 */
    36,   /* freqval=1f9 */
    36,   /* freqval=1fa */
    36,   /* freqval=1fb */
    36,   /* freqval=1fc */
    36,   /* freqval=1fd */
    36,   /* freqval=1fe */
    36,   /* freqval=1ff */
    35,   /* freqval=200 */
    35,   /* freqval=201 */
    35,   /* freqval=202 */
    35,   /* freqval=203 */
    35,   /* freqval=204 */
    35,   /* freqval=205 */
    35,   /* freqval=206 */
    35,   /* freqval=207 */
    35,   /* freqval=208 */
    35,   /* freqval=209 */
    35,   /* freqval=20a */
    35,   /* freqval=20b */
    35,   /* freqval=20c */
    35,   /* freqval=20d */
    35,   /* freqval=20e */
    35,   /* freqval=20f */
    35,   /* freqval=210 */
    35,   /* freqval=211 */
    35,   /* freqval=212 */
    35,   /* freqval=213 */
    35,   /* freqval=214 */
    35,   /* freqval=215 */
    35,   /* freqval=216 */
    35,   /* freqval=217 */
    35,   /* freqval=218 */
    35,   /* freqval=219 */
    35,   /* freqval=21a */
    35,   /* freqval=21b */
    35,   /* freqval=21c */
    35,   /* freqval=21d */
    35,   /* freqval=21e */
    34,   /* freqval=21f */
    34,   /* freqval=220 */
    34,   /* freqval=221 */
    34,   /* freqval=222 */
    34,   /* freqval=223 */
    34,   /* freqval=224 */
    34,   /* freqval=225 */
    34,   /* freqval=226 */
    34,   /* freqval=227 */
    34,   /* freqval=228 */
    34,   /* freqval=229 */
    34,   /* freqval=22a */
    34,   /* freqval=22b */
    34,   /* freqval=22c */
    34,   /* freqval=22d */
    34,   /* freqval=22e */
    34,   /* freqval=22f */
    34,   /* freqval=230 */
    34,   /* freqval=231 */
    34,   /* freqval=232 */
    34,   /* freqval=233 */
    34,   /* freqval=234 */
    34,   /* freqval=235 */
    34,   /* freqval=236 */
    34,   /* freqval=237 */
    34,   /* freqval=238 */
    34,   /* freqval=239 */
    34,   /* freqval=23a */
    34,   /* freqval=23b */
    34,   /* freqval=23c */
    34,   /* freqval=23d */
    34,   /* freqval=23e */
    33,   /* freqval=23f */
    33,   /* freqval=240 */
    33,   /* freqval=241 */
    33,   /* freqval=242 */
    33,   /* freqval=243 */
    33,   /* freqval=244 */
    33,   /* freqval=245 */
    33,   /* freqval=246 */
    33,   /* freqval=247 */
    33,   /* freqval=248 */
    33,   /* freqval=249 */
    33,   /* freqval=24a */
    33,   /* freqval=24b */
    33,   /* freqval=24c */
    33,   /* freqval=24d */
    33,   /* freqval=24e */
    33,   /* freqval=24f */
    33,   /* freqval=250 */
    33,   /* freqval=251 */
    33,   /* freqval=252 */
    33,   /* freqval=253 */
    33,   /* freqval=254 */
    33,   /* freqval=255 */
    33,   /* freqval=256 */
    33,   /* freqval=257 */
    33,   /* freqval=258 */
    33,   /* freqval=259 */
    33,   /* freqval=25a */
    33,   /* freqval=25b */
    33,   /* freqval=25c */
    33,   /* freqval=25d */
    33,   /* freqval=25e */
    33,   /* freqval=25f */
    33,   /* freqval=260 */
    32,   /* freqval=261 */
    32,   /* freqval=262 */
    32,   /* freqval=263 */
    32,   /* freqval=264 */
    32,   /* freqval=265 */
    32,   /* freqval=266 */
    32,   /* freqval=267 */
    32,   /* freqval=268 */
    32,   /* freqval=269 */
    32,   /* freqval=26a */
    32,   /* freqval=26b */
    32,   /* freqval=26c */
    32,   /* freqval=26d */
    32,   /* freqval=26e */
    32,   /* freqval=26f */
    32,   /* freqval=270 */
    32,   /* freqval=271 */
    32,   /* freqval=272 */
    32,   /* freqval=273 */
    32,   /* freqval=274 */
    32,   /* freqval=275 */
    32,   /* freqval=276 */
    32,   /* freqval=277 */
    32,   /* freqval=278 */
    32,   /* freqval=279 */
    32,   /* freqval=27a */
    32,   /* freqval=27b */
    32,   /* freqval=27c */
    32,   /* freqval=27d */
    32,   /* freqval=27e */
    32,   /* freqval=27f */
    32,   /* freqval=280 */
    32,   /* freqval=281 */
    32,   /* freqval=282 */
    32,   /* freqval=283 */
    32,   /* freqval=284 */
    31,   /* freqval=285 */
    31,   /* freqval=286 */
    31,   /* freqval=287 */
    31,   /* freqval=288 */
    31,   /* freqval=289 */
    31,   /* freqval=28a */
    31,   /* freqval=28b */
    31,   /* freqval=28c */
    31,   /* freqval=28d */
    31,   /* freqval=28e */
    31,   /* freqval=28f */
    31,   /* freqval=290 */
    31,   /* freqval=291 */
    31,   /* freqval=292 */
    31,   /* freqval=293 */
    31,   /* freqval=294 */
    31,   /* freqval=295 */
    31,   /* freqval=296 */
    31,   /* freqval=297 */
    31,   /* freqval=298 */
    31,   /* freqval=299 */
    31,   /* freqval=29a */
    31,   /* freqval=29b */
    31,   /* freqval=29c */
    31,   /* freqval=29d */
    31,   /* freqval=29e */
    31,   /* freqval=29f */
    31,   /* freqval=2a0 */
    31,   /* freqval=2a1 */
    31,   /* freqval=2a2 */
    31,   /* freqval=2a3 */
    31,   /* freqval=2a4 */
    31,   /* freqval=2a5 */
    31,   /* freqval=2a6 */
    31,   /* freqval=2a7 */
    31,   /* freqval=2a8 */
    31,   /* freqval=2a9 */
    31,   /* freqval=2aa */
    31,   /* freqval=2ab */
    30,   /* freqval=2ac */
    30,   /* freqval=2ad */
    30,   /* freqval=2ae */
    30,   /* freqval=2af */
    30,   /* freqval=2b0 */
    30,   /* freqval=2b1 */
    30,   /* freqval=2b2 */
    30,   /* freqval=2b3 */
    30,   /* freqval=2b4 */
    30,   /* freqval=2b5 */
    30,   /* freqval=2b6 */
    30,   /* freqval=2b7 */
    30,   /* freqval=2b8 */
    30,   /* freqval=2b9 */
    30,   /* freqval=2ba */
    30,   /* freqval=2bb */
    30,   /* freqval=2bc */
    30,   /* freqval=2bd */
    30,   /* freqval=2be */
    30,   /* freqval=2bf */
    30,   /* freqval=2c0 */
    30,   /* freqval=2c1 */
    30,   /* freqval=2c2 */
    30,   /* freqval=2c3 */
    30,   /* freqval=2c4 */
    30,   /* freqval=2c5 */
    30,   /* freqval=2c6 */
    30,   /* freqval=2c7 */
    30,   /* freqval=2c8 */
    30,   /* freqval=2c9 */
    30,   /* freqval=2ca */
    30,   /* freqval=2cb */
    30,   /* freqval=2cc */
    30,   /* freqval=2cd */
    30,   /* freqval=2ce */
    30,   /* freqval=2cf */
    30,   /* freqval=2d0 */
    30,   /* freqval=2d1 */
    30,   /* freqval=2d2 */
    30,   /* freqval=2d3 */
    29,   /* freqval=2d4 */
    29,   /* freqval=2d5 */
    29,   /* freqval=2d6 */
    29,   /* freqval=2d7 */
    29,   /* freqval=2d8 */
    29,   /* freqval=2d9 */
    29,   /* freqval=2da */
    29,   /* freqval=2db */
    29,   /* freqval=2dc */
    29,   /* freqval=2dd */
    29,   /* freqval=2de */
    29,   /* freqval=2df */
    29,   /* freqval=2e0 */
    29,   /* freqval=2e1 */
    29,   /* freqval=2e2 */
    29,   /* freqval=2e3 */
    29,   /* freqval=2e4 */
    29,   /* freqval=2e5 */
    29,   /* freqval=2e6 */
    29,   /* freqval=2e7 */
    29,   /* freqval=2e8 */
    29,   /* freqval=2e9 */
    29,   /* freqval=2ea */
    29,   /* freqval=2eb */
    29,   /* freqval=2ec */
    29,   /* freqval=2ed */
    29,   /* freqval=2ee */
    29,   /* freqval=2ef */
    29,   /* freqval=2f0 */
    29,   /* freqval=2f1 */
    29,   /* freqval=2f2 */
    29,   /* freqval=2f3 */
    29,   /* freqval=2f4 */
    29,   /* freqval=2f5 */
    29,   /* freqval=2f6 */
    29,   /* freqval=2f7 */
    29,   /* freqval=2f8 */
    29,   /* freqval=2f9 */
    29,   /* freqval=2fa */
    29,   /* freqval=2fb */
    29,   /* freqval=2fc */
    29,   /* freqval=2fd */
    29,   /* freqval=2fe */
    28,   /* freqval=2ff */
    28,   /* freqval=300 */
    28,   /* freqval=301 */
    28,   /* freqval=302 */
    28,   /* freqval=303 */
    28,   /* freqval=304 */
    28,   /* freqval=305 */
    28,   /* freqval=306 */
    28,   /* freqval=307 */
    28,   /* freqval=308 */
    28,   /* freqval=309 */
    28,   /* freqval=30a */
    28,   /* freqval=30b */
    28,   /* freqval=30c */
    28,   /* freqval=30d */
    28,   /* freqval=30e */
    28,   /* freqval=30f */
    28,   /* freqval=310 */
    28,   /* freqval=311 */
    28,   /* freqval=312 */
    28,   /* freqval=313 */
    28,   /* freqval=314 */
    28,   /* freqval=315 */
    28,   /* freqval=316 */
    28,   /* freqval=317 */
    28,   /* freqval=318 */
    28,   /* freqval=319 */
    28,   /* freqval=31a */
    28,   /* freqval=31b */
    28,   /* freqval=31c */
    28,   /* freqval=31d */
    28,   /* freqval=31e */
    28,   /* freqval=31f */
    28,   /* freqval=320 */
    28,   /* freqval=321 */
    28,   /* freqval=322 */
    28,   /* freqval=323 */
    28,   /* freqval=324 */
    28,   /* freqval=325 */
    28,   /* freqval=326 */
    28,   /* freqval=327 */
    28,   /* freqval=328 */
    28,   /* freqval=329 */
    28,   /* freqval=32a */
    28,   /* freqval=32b */
    28,   /* freqval=32c */
    27,   /* freqval=32d */
    27,   /* freqval=32e */
    27,   /* freqval=32f */
    27,   /* freqval=330 */
    27,   /* freqval=331 */
    27,   /* freqval=332 */
    27,   /* freqval=333 */
    27,   /* freqval=334 */
    27,   /* freqval=335 */
    27,   /* freqval=336 */
    27,   /* freqval=337 */
    27,   /* freqval=338 */
    27,   /* freqval=339 */
    27,   /* freqval=33a */
    27,   /* freqval=33b */
    27,   /* freqval=33c */
    27,   /* freqval=33d */
    27,   /* freqval=33e */
    27,   /* freqval=33f */
    27,   /* freqval=340 */
    27,   /* freqval=341 */
    27,   /* freqval=342 */
    27,   /* freqval=343 */
    27,   /* freqval=344 */
    27,   /* freqval=345 */
    27,   /* freqval=346 */
    27,   /* freqval=347 */
    27,   /* freqval=348 */
    27,   /* freqval=349 */
    27,   /* freqval=34a */
    27,   /* freqval=34b */
    27,   /* freqval=34c */
    27,   /* freqval=34d */
    27,   /* freqval=34e */
    27,   /* freqval=34f */
    27,   /* freqval=350 */
    27,   /* freqval=351 */
    27,   /* freqval=352 */
    27,   /* freqval=353 */
    27,   /* freqval=354 */
    27,   /* freqval=355 */
    27,   /* freqval=356 */
    27,   /* freqval=357 */
    27,   /* freqval=358 */
    27,   /* freqval=359 */
    27,   /* freqval=35a */
    27,   /* freqval=35b */
    27,   /* freqval=35c */
    26,   /* freqval=35d */
    26,   /* freqval=35e */
    26,   /* freqval=35f */
    26,   /* freqval=360 */
    26,   /* freqval=361 */
    26,   /* freqval=362 */
    26,   /* freqval=363 */
    26,   /* freqval=364 */
    26,   /* freqval=365 */
    26,   /* freqval=366 */
    26,   /* freqval=367 */
    26,   /* freqval=368 */
    26,   /* freqval=369 */
    26,   /* freqval=36a */
    26,   /* freqval=36b */
    26,   /* freqval=36c */
    26,   /* freqval=36d */
    26,   /* freqval=36e */
    26,   /* freqval=36f */
    26,   /* freqval=370 */
    26,   /* freqval=371 */
    26,   /* freqval=372 */
    26,   /* freqval=373 */
    26,   /* freqval=374 */
    26,   /* freqval=375 */
    26,   /* freqval=376 */
    26,   /* freqval=377 */
    26,   /* freqval=378 */
    26,   /* freqval=379 */
    26,   /* freqval=37a */
    26,   /* freqval=37b */
    26,   /* freqval=37c */
    26,   /* freqval=37d */
    26,   /* freqval=37e */
    26,   /* freqval=37f */
    26,   /* freqval=380 */
    26,   /* freqval=381 */
    26,   /* freqval=382 */
    26,   /* freqval=383 */
    26,   /* freqval=384 */
    26,   /* freqval=385 */
    26,   /* freqval=386 */
    26,   /* freqval=387 */
    26,   /* freqval=388 */
    26,   /* freqval=389 */
    26,   /* freqval=38a */
    26,   /* freqval=38b */
    26,   /* freqval=38c */
    26,   /* freqval=38d */
    26,   /* freqval=38e */
    26,   /* freqval=38f */
    26,   /* freqval=390 */
    25,   /* freqval=391 */
    25,   /* freqval=392 */
    25,   /* freqval=393 */
    25,   /* freqval=394 */
    25,   /* freqval=395 */
    25,   /* freqval=396 */
    25,   /* freqval=397 */
    25,   /* freqval=398 */
    25,   /* freqval=399 */
    25,   /* freqval=39a */
    25,   /* freqval=39b */
    25,   /* freqval=39c */
    25,   /* freqval=39d */
    25,   /* freqval=39e */
    25,   /* freqval=39f */
    25,   /* freqval=3a0 */
    25,   /* freqval=3a1 */
    25,   /* freqval=3a2 */
    25,   /* freqval=3a3 */
    25,   /* freqval=3a4 */
    25,   /* freqval=3a5 */
    25,   /* freqval=3a6 */
    25,   /* freqval=3a7 */
    25,   /* freqval=3a8 */
    25,   /* freqval=3a9 */
    25,   /* freqval=3aa */
    25,   /* freqval=3ab */
    25,   /* freqval=3ac */
    25,   /* freqval=3ad */
    25,   /* freqval=3ae */
    25,   /* freqval=3af */
    25,   /* freqval=3b0 */
    25,   /* freqval=3b1 */
    25,   /* freqval=3b2 */
    25,   /* freqval=3b3 */
    25,   /* freqval=3b4 */
    25,   /* freqval=3b5 */
    25,   /* freqval=3b6 */
    25,   /* freqval=3b7 */
    25,   /* freqval=3b8 */
    25,   /* freqval=3b9 */
    25,   /* freqval=3ba */
    25,   /* freqval=3bb */
    25,   /* freqval=3bc */
    25,   /* freqval=3bd */
    25,   /* freqval=3be */
    25,   /* freqval=3bf */
    25,   /* freqval=3c0 */
    25,   /* freqval=3c1 */
    25,   /* freqval=3c2 */
    25,   /* freqval=3c3 */
    25,   /* freqval=3c4 */
    25,   /* freqval=3c5 */
    25,   /* freqval=3c6 */
    24,   /* freqval=3c7 */
    24,   /* freqval=3c8 */
    24,   /* freqval=3c9 */
    24,   /* freqval=3ca */
    24,   /* freqval=3cb */
    24,   /* freqval=3cc */
    24,   /* freqval=3cd */
    24,   /* freqval=3ce */
    24,   /* freqval=3cf */
    24,   /* freqval=3d0 */
    24,   /* freqval=3d1 */
    24,   /* freqval=3d2 */
    24,   /* freqval=3d3 */
    24,   /* freqval=3d4 */
    24,   /* freqval=3d5 */
    24,   /* freqval=3d6 */
    24,   /* freqval=3d7 */
    24,   /* freqval=3d8 */
    24,   /* freqval=3d9 */
    24,   /* freqval=3da */
    24,   /* freqval=3db */
    24,   /* freqval=3dc */
    24,   /* freqval=3dd */
    24,   /* freqval=3de */
    24,   /* freqval=3df */
    24,   /* freqval=3e0 */
    24,   /* freqval=3e1 */
    24,   /* freqval=3e2 */
    24,   /* freqval=3e3 */
    24,   /* freqval=3e4 */
    24,   /* freqval=3e5 */
    24,   /* freqval=3e6 */
    24,   /* freqval=3e7 */
    24,   /* freqval=3e8 */
    24,   /* freqval=3e9 */
    24,   /* freqval=3ea */
    24,   /* freqval=3eb */
    24,   /* freqval=3ec */
    24,   /* freqval=3ed */
    24,   /* freqval=3ee */
    24,   /* freqval=3ef */
    24,   /* freqval=3f0 */
    24,   /* freqval=3f1 */
    24,   /* freqval=3f2 */
    24,   /* freqval=3f3 */
    24,   /* freqval=3f4 */
    24,   /* freqval=3f5 */
    24,   /* freqval=3f6 */
    24,   /* freqval=3f7 */
    24,   /* freqval=3f8 */
    24,   /* freqval=3f9 */
    24,   /* freqval=3fa */
    24,   /* freqval=3fb */
    24,   /* freqval=3fc */
    24,   /* freqval=3fd */
    24,   /* freqval=3fe */
    24,   /* freqval=3ff */
    23,   /* freqval=400 */
    23,   /* freqval=401 */
    23,   /* freqval=402 */
    23,   /* freqval=403 */
    23,   /* freqval=404 */
    23,   /* freqval=405 */
    23,   /* freqval=406 */
    23,   /* freqval=407 */
    23,   /* freqval=408 */
    23,   /* freqval=409 */
    23,   /* freqval=40a */
    23,   /* freqval=40b */
    23,   /* freqval=40c */
    23,   /* freqval=40d */
    23,   /* freqval=40e */
    23,   /* freqval=40f */
    23,   /* freqval=410 */
    23,   /* freqval=411 */
    23,   /* freqval=412 */
    23,   /* freqval=413 */
    23,   /* freqval=414 */
    23,   /* freqval=415 */
    23,   /* freqval=416 */
    23,   /* freqval=417 */
    23,   /* freqval=418 */
    23,   /* freqval=419 */
    23,   /* freqval=41a */
    23,   /* freqval=41b */
    23,   /* freqval=41c */
    23,   /* freqval=41d */
    23,   /* freqval=41e */
    23,   /* freqval=41f */
    23,   /* freqval=420 */
    23,   /* freqval=421 */
    23,   /* freqval=422 */
    23,   /* freqval=423 */
    23,   /* freqval=424 */
    23,   /* freqval=425 */
    23,   /* freqval=426 */
    23,   /* freqval=427 */
    23,   /* freqval=428 */
    23,   /* freqval=429 */
    23,   /* freqval=42a */
    23,   /* freqval=42b */
    23,   /* freqval=42c */
    23,   /* freqval=42d */
    23,   /* freqval=42e */
    23,   /* freqval=42f */
    23,   /* freqval=430 */
    23,   /* freqval=431 */
    23,   /* freqval=432 */
    23,   /* freqval=433 */
    23,   /* freqval=434 */
    23,   /* freqval=435 */
    23,   /* freqval=436 */
    23,   /* freqval=437 */
    23,   /* freqval=438 */
    23,   /* freqval=439 */
    23,   /* freqval=43a */
    23,   /* freqval=43b */
    23,   /* freqval=43c */
    22,   /* freqval=43d */
    22,   /* freqval=43e */
    22,   /* freqval=43f */
    22,   /* freqval=440 */
    22,   /* freqval=441 */
    22,   /* freqval=442 */
    22,   /* freqval=443 */
    22,   /* freqval=444 */
    22,   /* freqval=445 */
    22,   /* freqval=446 */
    22,   /* freqval=447 */
    22,   /* freqval=448 */
    22,   /* freqval=449 */
    22,   /* freqval=44a */
    22,   /* freqval=44b */
    22,   /* freqval=44c */
    22,   /* freqval=44d */
    22,   /* freqval=44e */
    22,   /* freqval=44f */
    22,   /* freqval=450 */
    22,   /* freqval=451 */
    22,   /* freqval=452 */
    22,   /* freqval=453 */
    22,   /* freqval=454 */
    22,   /* freqval=455 */
    22,   /* freqval=456 */
    22,   /* freqval=457 */
    22,   /* freqval=458 */
    22,   /* freqval=459 */
    22,   /* freqval=45a */
    22,   /* freqval=45b */
    22,   /* freqval=45c */
    22,   /* freqval=45d */
    22,   /* freqval=45e */
    22,   /* freqval=45f */
    22,   /* freqval=460 */
    22,   /* freqval=461 */
    22,   /* freqval=462 */
    22,   /* freqval=463 */
    22,   /* freqval=464 */
    22,   /* freqval=465 */
    22,   /* freqval=466 */
    22,   /* freqval=467 */
    22,   /* freqval=468 */
    22,   /* freqval=469 */
    22,   /* freqval=46a */
    22,   /* freqval=46b */
    22,   /* freqval=46c */
    22,   /* freqval=46d */
    22,   /* freqval=46e */
    22,   /* freqval=46f */
    22,   /* freqval=470 */
    22,   /* freqval=471 */
    22,   /* freqval=472 */
    22,   /* freqval=473 */
    22,   /* freqval=474 */
    22,   /* freqval=475 */
    22,   /* freqval=476 */
    22,   /* freqval=477 */
    22,   /* freqval=478 */
    22,   /* freqval=479 */
    22,   /* freqval=47a */
    22,   /* freqval=47b */
    22,   /* freqval=47c */
    22,   /* freqval=47d */
    21,   /* freqval=47e */
    21,   /* freqval=47f */
    21,   /* freqval=480 */
    21,   /* freqval=481 */
    21,   /* freqval=482 */
    21,   /* freqval=483 */
    21,   /* freqval=484 */
    21,   /* freqval=485 */
    21,   /* freqval=486 */
    21,   /* freqval=487 */
    21,   /* freqval=488 */
    21,   /* freqval=489 */
    21,   /* freqval=48a */
    21,   /* freqval=48b */
    21,   /* freqval=48c */
    21,   /* freqval=48d */
    21,   /* freqval=48e */
    21,   /* freqval=48f */
    21,   /* freqval=490 */
    21,   /* freqval=491 */
    21,   /* freqval=492 */
    21,   /* freqval=493 */
    21,   /* freqval=494 */
    21,   /* freqval=495 */
    21,   /* freqval=496 */
    21,   /* freqval=497 */
    21,   /* freqval=498 */
    21,   /* freqval=499 */
    21,   /* freqval=49a */
    21,   /* freqval=49b */
    21,   /* freqval=49c */
    21,   /* freqval=49d */
    21,   /* freqval=49e */
    21,   /* freqval=49f */
    21,   /* freqval=4a0 */
    21,   /* freqval=4a1 */
    21,   /* freqval=4a2 */
    21,   /* freqval=4a3 */
    21,   /* freqval=4a4 */
    21,   /* freqval=4a5 */
    21,   /* freqval=4a6 */
    21,   /* freqval=4a7 */
    21,   /* freqval=4a8 */
    21,   /* freqval=4a9 */
    21,   /* freqval=4aa */
    21,   /* freqval=4ab */
    21,   /* freqval=4ac */
    21,   /* freqval=4ad */
    21,   /* freqval=4ae */
    21,   /* freqval=4af */
    21,   /* freqval=4b0 */
    21,   /* freqval=4b1 */
    21,   /* freqval=4b2 */
    21,   /* freqval=4b3 */
    21,   /* freqval=4b4 */
    21,   /* freqval=4b5 */
    21,   /* freqval=4b6 */
    21,   /* freqval=4b7 */
    21,   /* freqval=4b8 */
    21,   /* freqval=4b9 */
    21,   /* freqval=4ba */
    21,   /* freqval=4bb */
    21,   /* freqval=4bc */
    21,   /* freqval=4bd */
    21,   /* freqval=4be */
    21,   /* freqval=4bf */
    21,   /* freqval=4c0 */
    21,   /* freqval=4c1 */
    20,   /* freqval=4c2 */
    20,   /* freqval=4c3 */
    20,   /* freqval=4c4 */
    20,   /* freqval=4c5 */
    20,   /* freqval=4c6 */
    20,   /* freqval=4c7 */
    20,   /* freqval=4c8 */
    20,   /* freqval=4c9 */
    20,   /* freqval=4ca */
    20,   /* freqval=4cb */
    20,   /* freqval=4cc */
    20,   /* freqval=4cd */
    20,   /* freqval=4ce */
    20,   /* freqval=4cf */
    20,   /* freqval=4d0 */
    20,   /* freqval=4d1 */
    20,   /* freqval=4d2 */
    20,   /* freqval=4d3 */
    20,   /* freqval=4d4 */
    20,   /* freqval=4d5 */
    20,   /* freqval=4d6 */
    20,   /* freqval=4d7 */
    20,   /* freqval=4d8 */
    20,   /* freqval=4d9 */
    20,   /* freqval=4da */
    20,   /* freqval=4db */
    20,   /* freqval=4dc */
    20,   /* freqval=4dd */
    20,   /* freqval=4de */
    20,   /* freqval=4df */
    20,   /* freqval=4e0 */
    20,   /* freqval=4e1 */
    20,   /* freqval=4e2 */
    20,   /* freqval=4e3 */
    20,   /* freqval=4e4 */
    20,   /* freqval=4e5 */
    20,   /* freqval=4e6 */
    20,   /* freqval=4e7 */
    20,   /* freqval=4e8 */
    20,   /* freqval=4e9 */
    20,   /* freqval=4ea */
    20,   /* freqval=4eb */
    20,   /* freqval=4ec */
    20,   /* freqval=4ed */
    20,   /* freqval=4ee */
    20,   /* freqval=4ef */
    20,   /* freqval=4f0 */
    20,   /* freqval=4f1 */
    20,   /* freqval=4f2 */
    20,   /* freqval=4f3 */
    20,   /* freqval=4f4 */
    20,   /* freqval=4f5 */
    20,   /* freqval=4f6 */
    20,   /* freqval=4f7 */
    20,   /* freqval=4f8 */
    20,   /* freqval=4f9 */
    20,   /* freqval=4fa */
    20,   /* freqval=4fb */
    20,   /* freqval=4fc */
    20,   /* freqval=4fd */
    20,   /* freqval=4fe */
    20,   /* freqval=4ff */
    20,   /* freqval=500 */
    20,   /* freqval=501 */
    20,   /* freqval=502 */
    20,   /* freqval=503 */
    20,   /* freqval=504 */
    20,   /* freqval=505 */
    20,   /* freqval=506 */
    20,   /* freqval=507 */
    20,   /* freqval=508 */
    20,   /* freqval=509 */
    19,   /* freqval=50a */
    19,   /* freqval=50b */
    19,   /* freqval=50c */
    19,   /* freqval=50d */
    19,   /* freqval=50e */
    19,   /* freqval=50f */
    19,   /* freqval=510 */
    19,   /* freqval=511 */
    19,   /* freqval=512 */
    19,   /* freqval=513 */
    19,   /* freqval=514 */
    19,   /* freqval=515 */
    19,   /* freqval=516 */
    19,   /* freqval=517 */
    19,   /* freqval=518 */
    19,   /* freqval=519 */
    19,   /* freqval=51a */
    19,   /* freqval=51b */
    19,   /* freqval=51c */
    19,   /* freqval=51d */
    19,   /* freqval=51e */
    19,   /* freqval=51f */
    19,   /* freqval=520 */
    19,   /* freqval=521 */
    19,   /* freqval=522 */
    19,   /* freqval=523 */
    19,   /* freqval=524 */
    19,   /* freqval=525 */
    19,   /* freqval=526 */
    19,   /* freqval=527 */
    19,   /* freqval=528 */
    19,   /* freqval=529 */
    19,   /* freqval=52a */
    19,   /* freqval=52b */
    19,   /* freqval=52c */
    19,   /* freqval=52d */
    19,   /* freqval=52e */
    19,   /* freqval=52f */
    19,   /* freqval=530 */
    19,   /* freqval=531 */
    19,   /* freqval=532 */
    19,   /* freqval=533 */
    19,   /* freqval=534 */
    19,   /* freqval=535 */
    19,   /* freqval=536 */
    19,   /* freqval=537 */
    19,   /* freqval=538 */
    19,   /* freqval=539 */
    19,   /* freqval=53a */
    19,   /* freqval=53b */
    19,   /* freqval=53c */
    19,   /* freqval=53d */
    19,   /* freqval=53e */
    19,   /* freqval=53f */
    19,   /* freqval=540 */
    19,   /* freqval=541 */
    19,   /* freqval=542 */
    19,   /* freqval=543 */
    19,   /* freqval=544 */
    19,   /* freqval=545 */
    19,   /* freqval=546 */
    19,   /* freqval=547 */
    19,   /* freqval=548 */
    19,   /* freqval=549 */
    19,   /* freqval=54a */
    19,   /* freqval=54b */
    19,   /* freqval=54c */
    19,   /* freqval=54d */
    19,   /* freqval=54e */
    19,   /* freqval=54f */
    19,   /* freqval=550 */
    19,   /* freqval=551 */
    19,   /* freqval=552 */
    19,   /* freqval=553 */
    19,   /* freqval=554 */
    19,   /* freqval=555 */
    19,   /* freqval=556 */
    18,   /* freqval=557 */
    18,   /* freqval=558 */
    18,   /* freqval=559 */
    18,   /* freqval=55a */
    18,   /* freqval=55b */
    18,   /* freqval=55c */
    18,   /* freqval=55d */
    18,   /* freqval=55e */
    18,   /* freqval=55f */
    18,   /* freqval=560 */
    18,   /* freqval=561 */
    18,   /* freqval=562 */
    18,   /* freqval=563 */
    18,   /* freqval=564 */
    18,   /* freqval=565 */
    18,   /* freqval=566 */
    18,   /* freqval=567 */
    18,   /* freqval=568 */
    18,   /* freqval=569 */
    18,   /* freqval=56a */
    18,   /* freqval=56b */
    18,   /* freqval=56c */
    18,   /* freqval=56d */
    18,   /* freqval=56e */
    18,   /* freqval=56f */
    18,   /* freqval=570 */
    18,   /* freqval=571 */
    18,   /* freqval=572 */
    18,   /* freqval=573 */
    18,   /* freqval=574 */
    18,   /* freqval=575 */
    18,   /* freqval=576 */
    18,   /* freqval=577 */
    18,   /* freqval=578 */
    18,   /* freqval=579 */
    18,   /* freqval=57a */
    18,   /* freqval=57b */
    18,   /* freqval=57c */
    18,   /* freqval=57d */
    18,   /* freqval=57e */
    18,   /* freqval=57f */
    18,   /* freqval=580 */
    18,   /* freqval=581 */
    18,   /* freqval=582 */
    18,   /* freqval=583 */
    18,   /* freqval=584 */
    18,   /* freqval=585 */
    18,   /* freqval=586 */
    18,   /* freqval=587 */
    18,   /* freqval=588 */
    18,   /* freqval=589 */
    18,   /* freqval=58a */
    18,   /* freqval=58b */
    18,   /* freqval=58c */
    18,   /* freqval=58d */
    18,   /* freqval=58e */
    18,   /* freqval=58f */
    18,   /* freqval=590 */
    18,   /* freqval=591 */
    18,   /* freqval=592 */
    18,   /* freqval=593 */
    18,   /* freqval=594 */
    18,   /* freqval=595 */
    18,   /* freqval=596 */
    18,   /* freqval=597 */
    18,   /* freqval=598 */
    18,   /* freqval=599 */
    18,   /* freqval=59a */
    18,   /* freqval=59b */
    18,   /* freqval=59c */
    18,   /* freqval=59d */
    18,   /* freqval=59e */
    18,   /* freqval=59f */
    18,   /* freqval=5a0 */
    18,   /* freqval=5a1 */
    18,   /* freqval=5a2 */
    18,   /* freqval=5a3 */
    18,   /* freqval=5a4 */
    18,   /* freqval=5a5 */
    18,   /* freqval=5a6 */
    18,   /* freqval=5a7 */
    17,   /* freqval=5a8 */
    17,   /* freqval=5a9 */
    17,   /* freqval=5aa */
    17,   /* freqval=5ab */
    17,   /* freqval=5ac */
    17,   /* freqval=5ad */
    17,   /* freqval=5ae */
    17,   /* freqval=5af */
    17,   /* freqval=5b0 */
    17,   /* freqval=5b1 */
    17,   /* freqval=5b2 */
    17,   /* freqval=5b3 */
    17,   /* freqval=5b4 */
    17,   /* freqval=5b5 */
    17,   /* freqval=5b6 */
    17,   /* freqval=5b7 */
    17,   /* freqval=5b8 */
    17,   /* freqval=5b9 */
    17,   /* freqval=5ba */
    17,   /* freqval=5bb */
    17,   /* freqval=5bc */
    17,   /* freqval=5bd */
    17,   /* freqval=5be */
    17,   /* freqval=5bf */
    17,   /* freqval=5c0 */
    17,   /* freqval=5c1 */
    17,   /* freqval=5c2 */
    17,   /* freqval=5c3 */
    17,   /* freqval=5c4 */
    17,   /* freqval=5c5 */
    17,   /* freqval=5c6 */
    17,   /* freqval=5c7 */
    17,   /* freqval=5c8 */
    17,   /* freqval=5c9 */
    17,   /* freqval=5ca */
    17,   /* freqval=5cb */
    17,   /* freqval=5cc */
    17,   /* freqval=5cd */
    17,   /* freqval=5ce */
    17,   /* freqval=5cf */
    17,   /* freqval=5d0 */
    17,   /* freqval=5d1 */
    17,   /* freqval=5d2 */
    17,   /* freqval=5d3 */
    17,   /* freqval=5d4 */
    17,   /* freqval=5d5 */
    17,   /* freqval=5d6 */
    17,   /* freqval=5d7 */
    17,   /* freqval=5d8 */
    17,   /* freqval=5d9 */
    17,   /* freqval=5da */
    17,   /* freqval=5db */
    17,   /* freqval=5dc */
    17,   /* freqval=5dd */
    17,   /* freqval=5de */
    17,   /* freqval=5df */
    17,   /* freqval=5e0 */
    17,   /* freqval=5e1 */
    17,   /* freqval=5e2 */
    17,   /* freqval=5e3 */
    17,   /* freqval=5e4 */
    17,   /* freqval=5e5 */
    17,   /* freqval=5e6 */
    17,   /* freqval=5e7 */
    17,   /* freqval=5e8 */
    17,   /* freqval=5e9 */
    17,   /* freqval=5ea */
    17,   /* freqval=5eb */
    17,   /* freqval=5ec */
    17,   /* freqval=5ed */
    17,   /* freqval=5ee */
    17,   /* freqval=5ef */
    17,   /* freqval=5f0 */
    17,   /* freqval=5f1 */
    17,   /* freqval=5f2 */
    17,   /* freqval=5f3 */
    17,   /* freqval=5f4 */
    17,   /* freqval=5f5 */
    17,   /* freqval=5f6 */
    17,   /* freqval=5f7 */
    17,   /* freqval=5f8 */
    17,   /* freqval=5f9 */
    17,   /* freqval=5fa */
    17,   /* freqval=5fb */
    17,   /* freqval=5fc */
    17,   /* freqval=5fd */
    16,   /* freqval=5fe */
    16,   /* freqval=5ff */
    16,   /* freqval=600 */
    16,   /* freqval=601 */
    16,   /* freqval=602 */
    16,   /* freqval=603 */
    16,   /* freqval=604 */
    16,   /* freqval=605 */
    16,   /* freqval=606 */
    16,   /* freqval=607 */
    16,   /* freqval=608 */
    16,   /* freqval=609 */
    16,   /* freqval=60a */
    16,   /* freqval=60b */
    16,   /* freqval=60c */
    16,   /* freqval=60d */
    16,   /* freqval=60e */
    16,   /* freqval=60f */
    16,   /* freqval=610 */
    16,   /* freqval=611 */
    16,   /* freqval=612 */
    16,   /* freqval=613 */
    16,   /* freqval=614 */
    16,   /* freqval=615 */
    16,   /* freqval=616 */
    16,   /* freqval=617 */
    16,   /* freqval=618 */
    16,   /* freqval=619 */
    16,   /* freqval=61a */
    16,   /* freqval=61b */
    16,   /* freqval=61c */
    16,   /* freqval=61d */
    16,   /* freqval=61e */
    16,   /* freqval=61f */
    16,   /* freqval=620 */
    16,   /* freqval=621 */
    16,   /* freqval=622 */
    16,   /* freqval=623 */
    16,   /* freqval=624 */
    16,   /* freqval=625 */
    16,   /* freqval=626 */
    16,   /* freqval=627 */
    16,   /* freqval=628 */
    16,   /* freqval=629 */
    16,   /* freqval=62a */
    16,   /* freqval=62b */
    16,   /* freqval=62c */
    16,   /* freqval=62d */
    16,   /* freqval=62e */
    16,   /* freqval=62f */
    16,   /* freqval=630 */
    16,   /* freqval=631 */
    16,   /* freqval=632 */
    16,   /* freqval=633 */
    16,   /* freqval=634 */
    16,   /* freqval=635 */
    16,   /* freqval=636 */
    16,   /* freqval=637 */
    16,   /* freqval=638 */
    16,   /* freqval=639 */
    16,   /* freqval=63a */
    16,   /* freqval=63b */
    16,   /* freqval=63c */
    16,   /* freqval=63d */
    16,   /* freqval=63e */
    16,   /* freqval=63f */
    16,   /* freqval=640 */
    16,   /* freqval=641 */
    16,   /* freqval=642 */
    16,   /* freqval=643 */
    16,   /* freqval=644 */
    16,   /* freqval=645 */
    16,   /* freqval=646 */
    16,   /* freqval=647 */
    16,   /* freqval=648 */
    16,   /* freqval=649 */
    16,   /* freqval=64a */
    16,   /* freqval=64b */
    16,   /* freqval=64c */
    16,   /* freqval=64d */
    16,   /* freqval=64e */
    16,   /* freqval=64f */
    16,   /* freqval=650 */
    16,   /* freqval=651 */
    16,   /* freqval=652 */
    16,   /* freqval=653 */
    16,   /* freqval=654 */
    16,   /* freqval=655 */
    16,   /* freqval=656 */
    16,   /* freqval=657 */
    16,   /* freqval=658 */
    16,   /* freqval=659 */
    15,   /* freqval=65a */
    15,   /* freqval=65b */
    15,   /* freqval=65c */
    15,   /* freqval=65d */
    15,   /* freqval=65e */
    15,   /* freqval=65f */
    15,   /* freqval=660 */
    15,   /* freqval=661 */
    15,   /* freqval=662 */
    15,   /* freqval=663 */
    15,   /* freqval=664 */
    15,   /* freqval=665 */
    15,   /* freqval=666 */
    15,   /* freqval=667 */
    15,   /* freqval=668 */
    15,   /* freqval=669 */
    15,   /* freqval=66a */
    15,   /* freqval=66b */
    15,   /* freqval=66c */
    15,   /* freqval=66d */
    15,   /* freqval=66e */
    15,   /* freqval=66f */
    15,   /* freqval=670 */
    15,   /* freqval=671 */
    15,   /* freqval=672 */
    15,   /* freqval=673 */
    15,   /* freqval=674 */
    15,   /* freqval=675 */
    15,   /* freqval=676 */
    15,   /* freqval=677 */
    15,   /* freqval=678 */
    15,   /* freqval=679 */
    15,   /* freqval=67a */
    15,   /* freqval=67b */
    15,   /* freqval=67c */
    15,   /* freqval=67d */
    15,   /* freqval=67e */
    15,   /* freqval=67f */
    15,   /* freqval=680 */
    15,   /* freqval=681 */
    15,   /* freqval=682 */
    15,   /* freqval=683 */
    15,   /* freqval=684 */
    15,   /* freqval=685 */
    15,   /* freqval=686 */
    15,   /* freqval=687 */
    15,   /* freqval=688 */
    15,   /* freqval=689 */
    15,   /* freqval=68a */
    15,   /* freqval=68b */
    15,   /* freqval=68c */
    15,   /* freqval=68d */
    15,   /* freqval=68e */
    15,   /* freqval=68f */
    15,   /* freqval=690 */
    15,   /* freqval=691 */
    15,   /* freqval=692 */
    15,   /* freqval=693 */
    15,   /* freqval=694 */
    15,   /* freqval=695 */
    15,   /* freqval=696 */
    15,   /* freqval=697 */
    15,   /* freqval=698 */
    15,   /* freqval=699 */
    15,   /* freqval=69a */
    15,   /* freqval=69b */
    15,   /* freqval=69c */
    15,   /* freqval=69d */
    15,   /* freqval=69e */
    15,   /* freqval=69f */
    15,   /* freqval=6a0 */
    15,   /* freqval=6a1 */
    15,   /* freqval=6a2 */
    15,   /* freqval=6a3 */
    15,   /* freqval=6a4 */
    15,   /* freqval=6a5 */
    15,   /* freqval=6a6 */
    15,   /* freqval=6a7 */
    15,   /* freqval=6a8 */
    15,   /* freqval=6a9 */
    15,   /* freqval=6aa */
    15,   /* freqval=6ab */
    15,   /* freqval=6ac */
    15,   /* freqval=6ad */
    15,   /* freqval=6ae */
    15,   /* freqval=6af */
    15,   /* freqval=6b0 */
    15,   /* freqval=6b1 */
    15,   /* freqval=6b2 */
    15,   /* freqval=6b3 */
    15,   /* freqval=6b4 */
    15,   /* freqval=6b5 */
    15,   /* freqval=6b6 */
    15,   /* freqval=6b7 */
    15,   /* freqval=6b8 */
    15,   /* freqval=6b9 */
    14,   /* freqval=6ba */
    14,   /* freqval=6bb */
    14,   /* freqval=6bc */
    14,   /* freqval=6bd */
    14,   /* freqval=6be */
    14,   /* freqval=6bf */
    14,   /* freqval=6c0 */
    14,   /* freqval=6c1 */
    14,   /* freqval=6c2 */
    14,   /* freqval=6c3 */
    14,   /* freqval=6c4 */
    14,   /* freqval=6c5 */
    14,   /* freqval=6c6 */
    14,   /* freqval=6c7 */
    14,   /* freqval=6c8 */
    14,   /* freqval=6c9 */
    14,   /* freqval=6ca */
    14,   /* freqval=6cb */
    14,   /* freqval=6cc */
    14,   /* freqval=6cd */
    14,   /* freqval=6ce */
    14,   /* freqval=6cf */
    14,   /* freqval=6d0 */
    14,   /* freqval=6d1 */
    14,   /* freqval=6d2 */
    14,   /* freqval=6d3 */
    14,   /* freqval=6d4 */
    14,   /* freqval=6d5 */
    14,   /* freqval=6d6 */
    14,   /* freqval=6d7 */
    14,   /* freqval=6d8 */
    14,   /* freqval=6d9 */
    14,   /* freqval=6da */
    14,   /* freqval=6db */
    14,   /* freqval=6dc */
    14,   /* freqval=6dd */
    14,   /* freqval=6de */
    14,   /* freqval=6df */
    14,   /* freqval=6e0 */
    14,   /* freqval=6e1 */
    14,   /* freqval=6e2 */
    14,   /* freqval=6e3 */
    14,   /* freqval=6e4 */
    14,   /* freqval=6e5 */
    14,   /* freqval=6e6 */
    14,   /* freqval=6e7 */
    14,   /* freqval=6e8 */
    14,   /* freqval=6e9 */
    14,   /* freqval=6ea */
    14,   /* freqval=6eb */
    14,   /* freqval=6ec */
    14,   /* freqval=6ed */
    14,   /* freqval=6ee */
    14,   /* freqval=6ef */
    14,   /* freqval=6f0 */
    14,   /* freqval=6f1 */
    14,   /* freqval=6f2 */
    14,   /* freqval=6f3 */
    14,   /* freqval=6f4 */
    14,   /* freqval=6f5 */
    14,   /* freqval=6f6 */
    14,   /* freqval=6f7 */
    14,   /* freqval=6f8 */
    14,   /* freqval=6f9 */
    14,   /* freqval=6fa */
    14,   /* freqval=6fb */
    14,   /* freqval=6fc */
    14,   /* freqval=6fd */
    14,   /* freqval=6fe */
    14,   /* freqval=6ff */
    14,   /* freqval=700 */
    14,   /* freqval=701 */
    14,   /* freqval=702 */
    14,   /* freqval=703 */
    14,   /* freqval=704 */
    14,   /* freqval=705 */
    14,   /* freqval=706 */
    14,   /* freqval=707 */
    14,   /* freqval=708 */
    14,   /* freqval=709 */
    14,   /* freqval=70a */
    14,   /* freqval=70b */
    14,   /* freqval=70c */
    14,   /* freqval=70d */
    14,   /* freqval=70e */
    14,   /* freqval=70f */
    14,   /* freqval=710 */
    14,   /* freqval=711 */
    14,   /* freqval=712 */
    14,   /* freqval=713 */
    14,   /* freqval=714 */
    14,   /* freqval=715 */
    14,   /* freqval=716 */
    14,   /* freqval=717 */
    14,   /* freqval=718 */
    14,   /* freqval=719 */
    14,   /* freqval=71a */
    14,   /* freqval=71b */
    14,   /* freqval=71c */
    14,   /* freqval=71d */
    14,   /* freqval=71e */
    14,   /* freqval=71f */
    14,   /* freqval=720 */
    13,   /* freqval=721 */
    13,   /* freqval=722 */
    13,   /* freqval=723 */
    13,   /* freqval=724 */
    13,   /* freqval=725 */
    13,   /* freqval=726 */
    13,   /* freqval=727 */
    13,   /* freqval=728 */
    13,   /* freqval=729 */
    13,   /* freqval=72a */
    13,   /* freqval=72b */
    13,   /* freqval=72c */
    13,   /* freqval=72d */
    13,   /* freqval=72e */
    13,   /* freqval=72f */
    13,   /* freqval=730 */
    13,   /* freqval=731 */
    13,   /* freqval=732 */
    13,   /* freqval=733 */
    13,   /* freqval=734 */
    13,   /* freqval=735 */
    13,   /* freqval=736 */
    13,   /* freqval=737 */
    13,   /* freqval=738 */
    13,   /* freqval=739 */
    13,   /* freqval=73a */
    13,   /* freqval=73b */
    13,   /* freqval=73c */
    13,   /* freqval=73d */
    13,   /* freqval=73e */
    13,   /* freqval=73f */
    13,   /* freqval=740 */
    13,   /* freqval=741 */
    13,   /* freqval=742 */
    13,   /* freqval=743 */
    13,   /* freqval=744 */
    13,   /* freqval=745 */
    13,   /* freqval=746 */
    13,   /* freqval=747 */
    13,   /* freqval=748 */
    13,   /* freqval=749 */
    13,   /* freqval=74a */
    13,   /* freqval=74b */
    13,   /* freqval=74c */
    13,   /* freqval=74d */
    13,   /* freqval=74e */
    13,   /* freqval=74f */
    13,   /* freqval=750 */
    13,   /* freqval=751 */
    13,   /* freqval=752 */
    13,   /* freqval=753 */
    13,   /* freqval=754 */
    13,   /* freqval=755 */
    13,   /* freqval=756 */
    13,   /* freqval=757 */
    13,   /* freqval=758 */
    13,   /* freqval=759 */
    13,   /* freqval=75a */
    13,   /* freqval=75b */
    13,   /* freqval=75c */
    13,   /* freqval=75d */
    13,   /* freqval=75e */
    13,   /* freqval=75f */
    13,   /* freqval=760 */
    13,   /* freqval=761 */
    13,   /* freqval=762 */
    13,   /* freqval=763 */
    13,   /* freqval=764 */
    13,   /* freqval=765 */
    13,   /* freqval=766 */
    13,   /* freqval=767 */
    13,   /* freqval=768 */
    13,   /* freqval=769 */
    13,   /* freqval=76a */
    13,   /* freqval=76b */
    13,   /* freqval=76c */
    13,   /* freqval=76d */
    13,   /* freqval=76e */
    13,   /* freqval=76f */
    13,   /* freqval=770 */
    13,   /* freqval=771 */
    13,   /* freqval=772 */
    13,   /* freqval=773 */
    13,   /* freqval=774 */
    13,   /* freqval=775 */
    13,   /* freqval=776 */
    13,   /* freqval=777 */
    13,   /* freqval=778 */
    13,   /* freqval=779 */
    13,   /* freqval=77a */
    13,   /* freqval=77b */
    13,   /* freqval=77c */
    13,   /* freqval=77d */
    13,   /* freqval=77e */
    13,   /* freqval=77f */
    13,   /* freqval=780 */
    13,   /* freqval=781 */
    13,   /* freqval=782 */
    13,   /* freqval=783 */
    13,   /* freqval=784 */
    13,   /* freqval=785 */
    13,   /* freqval=786 */
    13,   /* freqval=787 */
    13,   /* freqval=788 */
    13,   /* freqval=789 */
    13,   /* freqval=78a */
    13,   /* freqval=78b */
    13,   /* freqval=78c */
    12,   /* freqval=78d */
    12,   /* freqval=78e */
    12,   /* freqval=78f */
    12,   /* freqval=790 */
    12,   /* freqval=791 */
    12,   /* freqval=792 */
    12,   /* freqval=793 */
    12,   /* freqval=794 */
    12,   /* freqval=795 */
    12,   /* freqval=796 */
    12,   /* freqval=797 */
    12,   /* freqval=798 */
    12,   /* freqval=799 */
    12,   /* freqval=79a */
    12,   /* freqval=79b */
    12,   /* freqval=79c */
    12,   /* freqval=79d */
    12,   /* freqval=79e */
    12,   /* freqval=79f */
    12,   /* freqval=7a0 */
    12,   /* freqval=7a1 */
    12,   /* freqval=7a2 */
    12,   /* freqval=7a3 */
    12,   /* freqval=7a4 */
    12,   /* freqval=7a5 */
    12,   /* freqval=7a6 */
    12,   /* freqval=7a7 */
    12,   /* freqval=7a8 */
    12,   /* freqval=7a9 */
    12,   /* freqval=7aa */
    12,   /* freqval=7ab */
    12,   /* freqval=7ac */
    12,   /* freqval=7ad */
    12,   /* freqval=7ae */
    12,   /* freqval=7af */
    12,   /* freqval=7b0 */
    12,   /* freqval=7b1 */
    12,   /* freqval=7b2 */
    12,   /* freqval=7b3 */
    12,   /* freqval=7b4 */
    12,   /* freqval=7b5 */
    12,   /* freqval=7b6 */
    12,   /* freqval=7b7 */
    12,   /* freqval=7b8 */
    12,   /* freqval=7b9 */
    12,   /* freqval=7ba */
    12,   /* freqval=7bb */
    12,   /* freqval=7bc */
    12,   /* freqval=7bd */
    12,   /* freqval=7be */
    12,   /* freqval=7bf */
    12,   /* freqval=7c0 */
    12,   /* freqval=7c1 */
    12,   /* freqval=7c2 */
    12,   /* freqval=7c3 */
    12,   /* freqval=7c4 */
    12,   /* freqval=7c5 */
    12,   /* freqval=7c6 */
    12,   /* freqval=7c7 */
    12,   /* freqval=7c8 */
    12,   /* freqval=7c9 */
    12,   /* freqval=7ca */
    12,   /* freqval=7cb */
    12,   /* freqval=7cc */
    12,   /* freqval=7cd */
    12,   /* freqval=7ce */
    12,   /* freqval=7cf */
    12,   /* freqval=7d0 */
    12,   /* freqval=7d1 */
    12,   /* freqval=7d2 */
    12,   /* freqval=7d3 */
    12,   /* freqval=7d4 */
    12,   /* freqval=7d5 */
    12,   /* freqval=7d6 */
    12,   /* freqval=7d7 */
    12,   /* freqval=7d8 */
    12,   /* freqval=7d9 */
    12,   /* freqval=7da */
    12,   /* freqval=7db */
    12,   /* freqval=7dc */
    12,   /* freqval=7dd */
    12,   /* freqval=7de */
    12,   /* freqval=7df */
    12,   /* freqval=7e0 */
    12,   /* freqval=7e1 */
    12,   /* freqval=7e2 */
    12,   /* freqval=7e3 */
    12,   /* freqval=7e4 */
    12,   /* freqval=7e5 */
    12,   /* freqval=7e6 */
    12,   /* freqval=7e7 */
    12,   /* freqval=7e8 */
    12,   /* freqval=7e9 */
    12,   /* freqval=7ea */
    12,   /* freqval=7eb */
    12,   /* freqval=7ec */
    12,   /* freqval=7ed */
    12,   /* freqval=7ee */
    12,   /* freqval=7ef */
    12,   /* freqval=7f0 */
    12,   /* freqval=7f1 */
    12,   /* freqval=7f2 */
    12,   /* freqval=7f3 */
    12,   /* freqval=7f4 */
    12,   /* freqval=7f5 */
    12,   /* freqval=7f6 */
    12,   /* freqval=7f7 */
    12,   /* freqval=7f8 */
    12,   /* freqval=7f9 */
    12,   /* freqval=7fa */
    12,   /* freqval=7fb */
    12,   /* freqval=7fc */
    12,   /* freqval=7fd */
    12,   /* freqval=7fe */
    12,   /* freqval=7ff */
    11,   /* freqval=800 */
    11,   /* freqval=801 */
    11,   /* freqval=802 */
    11,   /* freqval=803 */
    11,   /* freqval=804 */
    11,   /* freqval=805 */
    11,   /* freqval=806 */
    11,   /* freqval=807 */
    11,   /* freqval=808 */
    11,   /* freqval=809 */
    11,   /* freqval=80a */
    11,   /* freqval=80b */
    11,   /* freqval=80c */
    11,   /* freqval=80d */
    11,   /* freqval=80e */
    11,   /* freqval=80f */
    11,   /* freqval=810 */
    11,   /* freqval=811 */
    11,   /* freqval=812 */
    11,   /* freqval=813 */
    11,   /* freqval=814 */
    11,   /* freqval=815 */
    11,   /* freqval=816 */
    11,   /* freqval=817 */
    11,   /* freqval=818 */
    11,   /* freqval=819 */
    11,   /* freqval=81a */
    11,   /* freqval=81b */
    11,   /* freqval=81c */
    11,   /* freqval=81d */
    11,   /* freqval=81e */
    11,   /* freqval=81f */
    11,   /* freqval=820 */
    11,   /* freqval=821 */
    11,   /* freqval=822 */
    11,   /* freqval=823 */
    11,   /* freqval=824 */
    11,   /* freqval=825 */
    11,   /* freqval=826 */
    11,   /* freqval=827 */
    11,   /* freqval=828 */
    11,   /* freqval=829 */
    11,   /* freqval=82a */
    11,   /* freqval=82b */
    11,   /* freqval=82c */
    11,   /* freqval=82d */
    11,   /* freqval=82e */
    11,   /* freqval=82f */
    11,   /* freqval=830 */
    11,   /* freqval=831 */
    11,   /* freqval=832 */
    11,   /* freqval=833 */
    11,   /* freqval=834 */
    11,   /* freqval=835 */
    11,   /* freqval=836 */
    11,   /* freqval=837 */
    11,   /* freqval=838 */
    11,   /* freqval=839 */
    11,   /* freqval=83a */
    11,   /* freqval=83b */
    11,   /* freqval=83c */
    11,   /* freqval=83d */
    11,   /* freqval=83e */
    11,   /* freqval=83f */
    11,   /* freqval=840 */
    11,   /* freqval=841 */
    11,   /* freqval=842 */
    11,   /* freqval=843 */
    11,   /* freqval=844 */
    11,   /* freqval=845 */
    11,   /* freqval=846 */
    11,   /* freqval=847 */
    11,   /* freqval=848 */
    11,   /* freqval=849 */
    11,   /* freqval=84a */
    11,   /* freqval=84b */
    11,   /* freqval=84c */
    11,   /* freqval=84d */
    11,   /* freqval=84e */
    11,   /* freqval=84f */
    11,   /* freqval=850 */
    11,   /* freqval=851 */
    11,   /* freqval=852 */
    11,   /* freqval=853 */
    11,   /* freqval=854 */
    11,   /* freqval=855 */
    11,   /* freqval=856 */
    11,   /* freqval=857 */
    11,   /* freqval=858 */
    11,   /* freqval=859 */
    11,   /* freqval=85a */
    11,   /* freqval=85b */
    11,   /* freqval=85c */
    11,   /* freqval=85d */
    11,   /* freqval=85e */
    11,   /* freqval=85f */
    11,   /* freqval=860 */
    11,   /* freqval=861 */
    11,   /* freqval=862 */
    11,   /* freqval=863 */
    11,   /* freqval=864 */
    11,   /* freqval=865 */
    11,   /* freqval=866 */
    11,   /* freqval=867 */
    11,   /* freqval=868 */
    11,   /* freqval=869 */
    11,   /* freqval=86a */
    11,   /* freqval=86b */
    11,   /* freqval=86c */
    11,   /* freqval=86d */
    11,   /* freqval=86e */
    11,   /* freqval=86f */
    11,   /* freqval=870 */
    11,   /* freqval=871 */
    11,   /* freqval=872 */
    11,   /* freqval=873 */
    11,   /* freqval=874 */
    11,   /* freqval=875 */
    11,   /* freqval=876 */
    11,   /* freqval=877 */
    11,   /* freqval=878 */
    11,   /* freqval=879 */
    10,   /* freqval=87a */
    10,   /* freqval=87b */
    10,   /* freqval=87c */
    10,   /* freqval=87d */
    10,   /* freqval=87e */
    10,   /* freqval=87f */
    10,   /* freqval=880 */
    10,   /* freqval=881 */
    10,   /* freqval=882 */
    10,   /* freqval=883 */
    10,   /* freqval=884 */
    10,   /* freqval=885 */
    10,   /* freqval=886 */
    10,   /* freqval=887 */
    10,   /* freqval=888 */
    10,   /* freqval=889 */
    10,   /* freqval=88a */
    10,   /* freqval=88b */
    10,   /* freqval=88c */
    10,   /* freqval=88d */
    10,   /* freqval=88e */
    10,   /* freqval=88f */
    10,   /* freqval=890 */
    10,   /* freqval=891 */
    10,   /* freqval=892 */
    10,   /* freqval=893 */
    10,   /* freqval=894 */
    10,   /* freqval=895 */
    10,   /* freqval=896 */
    10,   /* freqval=897 */
    10,   /* freqval=898 */
    10,   /* freqval=899 */
    10,   /* freqval=89a */
    10,   /* freqval=89b */
    10,   /* freqval=89c */
    10,   /* freqval=89d */
    10,   /* freqval=89e */
    10,   /* freqval=89f */
    10,   /* freqval=8a0 */
    10,   /* freqval=8a1 */
    10,   /* freqval=8a2 */
    10,   /* freqval=8a3 */
    10,   /* freqval=8a4 */
    10,   /* freqval=8a5 */
    10,   /* freqval=8a6 */
    10,   /* freqval=8a7 */
    10,   /* freqval=8a8 */
    10,   /* freqval=8a9 */
    10,   /* freqval=8aa */
    10,   /* freqval=8ab */
    10,   /* freqval=8ac */
    10,   /* freqval=8ad */
    10,   /* freqval=8ae */
    10,   /* freqval=8af */
    10,   /* freqval=8b0 */
    10,   /* freqval=8b1 */
    10,   /* freqval=8b2 */
    10,   /* freqval=8b3 */
    10,   /* freqval=8b4 */
    10,   /* freqval=8b5 */
    10,   /* freqval=8b6 */
    10,   /* freqval=8b7 */
    10,   /* freqval=8b8 */
    10,   /* freqval=8b9 */
    10,   /* freqval=8ba */
    10,   /* freqval=8bb */
    10,   /* freqval=8bc */
    10,   /* freqval=8bd */
    10,   /* freqval=8be */
    10,   /* freqval=8bf */
    10,   /* freqval=8c0 */
    10,   /* freqval=8c1 */
    10,   /* freqval=8c2 */
    10,   /* freqval=8c3 */
    10,   /* freqval=8c4 */
    10,   /* freqval=8c5 */
    10,   /* freqval=8c6 */
    10,   /* freqval=8c7 */
    10,   /* freqval=8c8 */
    10,   /* freqval=8c9 */
    10,   /* freqval=8ca */
    10,   /* freqval=8cb */
    10,   /* freqval=8cc */
    10,   /* freqval=8cd */
    10,   /* freqval=8ce */
    10,   /* freqval=8cf */
    10,   /* freqval=8d0 */
    10,   /* freqval=8d1 */
    10,   /* freqval=8d2 */
    10,   /* freqval=8d3 */
    10,   /* freqval=8d4 */
    10,   /* freqval=8d5 */
    10,   /* freqval=8d6 */
    10,   /* freqval=8d7 */
    10,   /* freqval=8d8 */
    10,   /* freqval=8d9 */
    10,   /* freqval=8da */
    10,   /* freqval=8db */
    10,   /* freqval=8dc */
    10,   /* freqval=8dd */
    10,   /* freqval=8de */
    10,   /* freqval=8df */
    10,   /* freqval=8e0 */
    10,   /* freqval=8e1 */
    10,   /* freqval=8e2 */
    10,   /* freqval=8e3 */
    10,   /* freqval=8e4 */
    10,   /* freqval=8e5 */
    10,   /* freqval=8e6 */
    10,   /* freqval=8e7 */
    10,   /* freqval=8e8 */
    10,   /* freqval=8e9 */
    10,   /* freqval=8ea */
    10,   /* freqval=8eb */
    10,   /* freqval=8ec */
    10,   /* freqval=8ed */
    10,   /* freqval=8ee */
    10,   /* freqval=8ef */
    10,   /* freqval=8f0 */
    10,   /* freqval=8f1 */
    10,   /* freqval=8f2 */
    10,   /* freqval=8f3 */
    10,   /* freqval=8f4 */
    10,   /* freqval=8f5 */
    10,   /* freqval=8f6 */
    10,   /* freqval=8f7 */
    10,   /* freqval=8f8 */
    10,   /* freqval=8f9 */
    10,   /* freqval=8fa */
    9,    /* freqval=8fb */
    9,    /* freqval=8fc */
    9,    /* freqval=8fd */
    9,    /* freqval=8fe */
    9,    /* freqval=8ff */
    9,    /* freqval=900 */
    9,    /* freqval=901 */
    9,    /* freqval=902 */
    9,    /* freqval=903 */
    9,    /* freqval=904 */
    9,    /* freqval=905 */
    9,    /* freqval=906 */
    9,    /* freqval=907 */
    9,    /* freqval=908 */
    9,    /* freqval=909 */
    9,    /* freqval=90a */
    9,    /* freqval=90b */
    9,    /* freqval=90c */
    9,    /* freqval=90d */
    9,    /* freqval=90e */
    9,    /* freqval=90f */
    9,    /* freqval=910 */
    9,    /* freqval=911 */
    9,    /* freqval=912 */
    9,    /* freqval=913 */
    9,    /* freqval=914 */
    9,    /* freqval=915 */
    9,    /* freqval=916 */
    9,    /* freqval=917 */
    9,    /* freqval=918 */
    9,    /* freqval=919 */
    9,    /* freqval=91a */
    9,    /* freqval=91b */
    9,    /* freqval=91c */
    9,    /* freqval=91d */
    9,    /* freqval=91e */
    9,    /* freqval=91f */
    9,    /* freqval=920 */
    9,    /* freqval=921 */
    9,    /* freqval=922 */
    9,    /* freqval=923 */
    9,    /* freqval=924 */
    9,    /* freqval=925 */
    9,    /* freqval=926 */
    9,    /* freqval=927 */
    9,    /* freqval=928 */
    9,    /* freqval=929 */
    9,    /* freqval=92a */
    9,    /* freqval=92b */
    9,    /* freqval=92c */
    9,    /* freqval=92d */
    9,    /* freqval=92e */
    9,    /* freqval=92f */
    9,    /* freqval=930 */
    9,    /* freqval=931 */
    9,    /* freqval=932 */
    9,    /* freqval=933 */
    9,    /* freqval=934 */
    9,    /* freqval=935 */
    9,    /* freqval=936 */
    9,    /* freqval=937 */
    9,    /* freqval=938 */
    9,    /* freqval=939 */
    9,    /* freqval=93a */
    9,    /* freqval=93b */
    9,    /* freqval=93c */
    9,    /* freqval=93d */
    9,    /* freqval=93e */
    9,    /* freqval=93f */
    9,    /* freqval=940 */
    9,    /* freqval=941 */
    9,    /* freqval=942 */
    9,    /* freqval=943 */
    9,    /* freqval=944 */
    9,    /* freqval=945 */
    9,    /* freqval=946 */
    9,    /* freqval=947 */
    9,    /* freqval=948 */
    9,    /* freqval=949 */
    9,    /* freqval=94a */
    9,    /* freqval=94b */
    9,    /* freqval=94c */
    9,    /* freqval=94d */
    9,    /* freqval=94e */
    9,    /* freqval=94f */
    9,    /* freqval=950 */
    9,    /* freqval=951 */
    9,    /* freqval=952 */
    9,    /* freqval=953 */
    9,    /* freqval=954 */
    9,    /* freqval=955 */
    9,    /* freqval=956 */
    9,    /* freqval=957 */
    9,    /* freqval=958 */
    9,    /* freqval=959 */
    9,    /* freqval=95a */
    9,    /* freqval=95b */
    9,    /* freqval=95c */
    9,    /* freqval=95d */
    9,    /* freqval=95e */
    9,    /* freqval=95f */
    9,    /* freqval=960 */
    9,    /* freqval=961 */
    9,    /* freqval=962 */
    9,    /* freqval=963 */
    9,    /* freqval=964 */
    9,    /* freqval=965 */
    9,    /* freqval=966 */
    9,    /* freqval=967 */
    9,    /* freqval=968 */
    9,    /* freqval=969 */
    9,    /* freqval=96a */
    9,    /* freqval=96b */
    9,    /* freqval=96c */
    9,    /* freqval=96d */
    9,    /* freqval=96e */
    9,    /* freqval=96f */
    9,    /* freqval=970 */
    9,    /* freqval=971 */
    9,    /* freqval=972 */
    9,    /* freqval=973 */
    9,    /* freqval=974 */
    9,    /* freqval=975 */
    9,    /* freqval=976 */
    9,    /* freqval=977 */
    9,    /* freqval=978 */
    9,    /* freqval=979 */
    9,    /* freqval=97a */
    9,    /* freqval=97b */
    9,    /* freqval=97c */
    9,    /* freqval=97d */
    9,    /* freqval=97e */
    9,    /* freqval=97f */
    9,    /* freqval=980 */
    9,    /* freqval=981 */
    9,    /* freqval=982 */
    8,    /* freqval=983 */
    8,    /* freqval=984 */
    8,    /* freqval=985 */
    8,    /* freqval=986 */
    8,    /* freqval=987 */
    8,    /* freqval=988 */
    8,    /* freqval=989 */
    8,    /* freqval=98a */
    8,    /* freqval=98b */
    8,    /* freqval=98c */
    8,    /* freqval=98d */
    8,    /* freqval=98e */
    8,    /* freqval=98f */
    8,    /* freqval=990 */
    8,    /* freqval=991 */
    8,    /* freqval=992 */
    8,    /* freqval=993 */
    8,    /* freqval=994 */
    8,    /* freqval=995 */
    8,    /* freqval=996 */
    8,    /* freqval=997 */
    8,    /* freqval=998 */
    8,    /* freqval=999 */
    8,    /* freqval=99a */
    8,    /* freqval=99b */
    8,    /* freqval=99c */
    8,    /* freqval=99d */
    8,    /* freqval=99e */
    8,    /* freqval=99f */
    8,    /* freqval=9a0 */
    8,    /* freqval=9a1 */
    8,    /* freqval=9a2 */
    8,    /* freqval=9a3 */
    8,    /* freqval=9a4 */
    8,    /* freqval=9a5 */
    8,    /* freqval=9a6 */
    8,    /* freqval=9a7 */
    8,    /* freqval=9a8 */
    8,    /* freqval=9a9 */
    8,    /* freqval=9aa */
    8,    /* freqval=9ab */
    8,    /* freqval=9ac */
    8,    /* freqval=9ad */
    8,    /* freqval=9ae */
    8,    /* freqval=9af */
    8,    /* freqval=9b0 */
    8,    /* freqval=9b1 */
    8,    /* freqval=9b2 */
    8,    /* freqval=9b3 */
    8,    /* freqval=9b4 */
    8,    /* freqval=9b5 */
    8,    /* freqval=9b6 */
    8,    /* freqval=9b7 */
    8,    /* freqval=9b8 */
    8,    /* freqval=9b9 */
    8,    /* freqval=9ba */
    8,    /* freqval=9bb */
    8,    /* freqval=9bc */
    8,    /* freqval=9bd */
    8,    /* freqval=9be */
    8,    /* freqval=9bf */
    8,    /* freqval=9c0 */
    8,    /* freqval=9c1 */
    8,    /* freqval=9c2 */
    8,    /* freqval=9c3 */
    8,    /* freqval=9c4 */
    8,    /* freqval=9c5 */
    8,    /* freqval=9c6 */
    8,    /* freqval=9c7 */
    8,    /* freqval=9c8 */
    8,    /* freqval=9c9 */
    8,    /* freqval=9ca */
    8,    /* freqval=9cb */
    8,    /* freqval=9cc */
    8,    /* freqval=9cd */
    8,    /* freqval=9ce */
    8,    /* freqval=9cf */
    8,    /* freqval=9d0 */
    8,    /* freqval=9d1 */
    8,    /* freqval=9d2 */
    8,    /* freqval=9d3 */
    8,    /* freqval=9d4 */
    8,    /* freqval=9d5 */
    8,    /* freqval=9d6 */
    8,    /* freqval=9d7 */
    8,    /* freqval=9d8 */
    8,    /* freqval=9d9 */
    8,    /* freqval=9da */
    8,    /* freqval=9db */
    8,    /* freqval=9dc */
    8,    /* freqval=9dd */
    8,    /* freqval=9de */
    8,    /* freqval=9df */
    8,    /* freqval=9e0 */
    8,    /* freqval=9e1 */
    8,    /* freqval=9e2 */
    8,    /* freqval=9e3 */
    8,    /* freqval=9e4 */
    8,    /* freqval=9e5 */
    8,    /* freqval=9e6 */
    8,    /* freqval=9e7 */
    8,    /* freqval=9e8 */
    8,    /* freqval=9e9 */
    8,    /* freqval=9ea */
    8,    /* freqval=9eb */
    8,    /* freqval=9ec */
    8,    /* freqval=9ed */
    8,    /* freqval=9ee */
    8,    /* freqval=9ef */
    8,    /* freqval=9f0 */
    8,    /* freqval=9f1 */
    8,    /* freqval=9f2 */
    8,    /* freqval=9f3 */
    8,    /* freqval=9f4 */
    8,    /* freqval=9f5 */
    8,    /* freqval=9f6 */
    8,    /* freqval=9f7 */
    8,    /* freqval=9f8 */
    8,    /* freqval=9f9 */
    8,    /* freqval=9fa */
    8,    /* freqval=9fb */
    8,    /* freqval=9fc */
    8,    /* freqval=9fd */
    8,    /* freqval=9fe */
    8,    /* freqval=9ff */
    8,    /* freqval=a00 */
    8,    /* freqval=a01 */
    8,    /* freqval=a02 */
    8,    /* freqval=a03 */
    8,    /* freqval=a04 */
    8,    /* freqval=a05 */
    8,    /* freqval=a06 */
    8,    /* freqval=a07 */
    8,    /* freqval=a08 */
    8,    /* freqval=a09 */
    8,    /* freqval=a0a */
    8,    /* freqval=a0b */
    8,    /* freqval=a0c */
    8,    /* freqval=a0d */
    8,    /* freqval=a0e */
    8,    /* freqval=a0f */
    8,    /* freqval=a10 */
    8,    /* freqval=a11 */
    8,    /* freqval=a12 */
    8,    /* freqval=a13 */
    7,    /* freqval=a14 */
    7,    /* freqval=a15 */
    7,    /* freqval=a16 */
    7,    /* freqval=a17 */
    7,    /* freqval=a18 */
    7,    /* freqval=a19 */
    7,    /* freqval=a1a */
    7,    /* freqval=a1b */
    7,    /* freqval=a1c */
    7,    /* freqval=a1d */
    7,    /* freqval=a1e */
    7,    /* freqval=a1f */
    7,    /* freqval=a20 */
    7,    /* freqval=a21 */
    7,    /* freqval=a22 */
    7,    /* freqval=a23 */
    7,    /* freqval=a24 */
    7,    /* freqval=a25 */
    7,    /* freqval=a26 */
    7,    /* freqval=a27 */
    7,    /* freqval=a28 */
    7,    /* freqval=a29 */
    7,    /* freqval=a2a */
    7,    /* freqval=a2b */
    7,    /* freqval=a2c */
    7,    /* freqval=a2d */
    7,    /* freqval=a2e */
    7,    /* freqval=a2f */
    7,    /* freqval=a30 */
    7,    /* freqval=a31 */
    7,    /* freqval=a32 */
    7,    /* freqval=a33 */
    7,    /* freqval=a34 */
    7,    /* freqval=a35 */
    7,    /* freqval=a36 */
    7,    /* freqval=a37 */
    7,    /* freqval=a38 */
    7,    /* freqval=a39 */
    7,    /* freqval=a3a */
    7,    /* freqval=a3b */
    7,    /* freqval=a3c */
    7,    /* freqval=a3d */
    7,    /* freqval=a3e */
    7,    /* freqval=a3f */
    7,    /* freqval=a40 */
    7,    /* freqval=a41 */
    7,    /* freqval=a42 */
    7,    /* freqval=a43 */
    7,    /* freqval=a44 */
    7,    /* freqval=a45 */
    7,    /* freqval=a46 */
    7,    /* freqval=a47 */
    7,    /* freqval=a48 */
    7,    /* freqval=a49 */
    7,    /* freqval=a4a */
    7,    /* freqval=a4b */
    7,    /* freqval=a4c */
    7,    /* freqval=a4d */
    7,    /* freqval=a4e */
    7,    /* freqval=a4f */
    7,    /* freqval=a50 */
    7,    /* freqval=a51 */
    7,    /* freqval=a52 */
    7,    /* freqval=a53 */
    7,    /* freqval=a54 */
    7,    /* freqval=a55 */
    7,    /* freqval=a56 */
    7,    /* freqval=a57 */
    7,    /* freqval=a58 */
    7,    /* freqval=a59 */
    7,    /* freqval=a5a */
    7,    /* freqval=a5b */
    7,    /* freqval=a5c */
    7,    /* freqval=a5d */
    7,    /* freqval=a5e */
    7,    /* freqval=a5f */
    7,    /* freqval=a60 */
    7,    /* freqval=a61 */
    7,    /* freqval=a62 */
    7,    /* freqval=a63 */
    7,    /* freqval=a64 */
    7,    /* freqval=a65 */
    7,    /* freqval=a66 */
    7,    /* freqval=a67 */
    7,    /* freqval=a68 */
    7,    /* freqval=a69 */
    7,    /* freqval=a6a */
    7,    /* freqval=a6b */
    7,    /* freqval=a6c */
    7,    /* freqval=a6d */
    7,    /* freqval=a6e */
    7,    /* freqval=a6f */
    7,    /* freqval=a70 */
    7,    /* freqval=a71 */
    7,    /* freqval=a72 */
    7,    /* freqval=a73 */
    7,    /* freqval=a74 */
    7,    /* freqval=a75 */
    7,    /* freqval=a76 */
    7,    /* freqval=a77 */
    7,    /* freqval=a78 */
    7,    /* freqval=a79 */
    7,    /* freqval=a7a */
    7,    /* freqval=a7b */
    7,    /* freqval=a7c */
    7,    /* freqval=a7d */
    7,    /* freqval=a7e */
    7,    /* freqval=a7f */
    7,    /* freqval=a80 */
    7,    /* freqval=a81 */
    7,    /* freqval=a82 */
    7,    /* freqval=a83 */
    7,    /* freqval=a84 */
    7,    /* freqval=a85 */
    7,    /* freqval=a86 */
    7,    /* freqval=a87 */
    7,    /* freqval=a88 */
    7,    /* freqval=a89 */
    7,    /* freqval=a8a */
    7,    /* freqval=a8b */
    7,    /* freqval=a8c */
    7,    /* freqval=a8d */
    7,    /* freqval=a8e */
    7,    /* freqval=a8f */
    7,    /* freqval=a90 */
    7,    /* freqval=a91 */
    7,    /* freqval=a92 */
    7,    /* freqval=a93 */
    7,    /* freqval=a94 */
    7,    /* freqval=a95 */
    7,    /* freqval=a96 */
    7,    /* freqval=a97 */
    7,    /* freqval=a98 */
    7,    /* freqval=a99 */
    7,    /* freqval=a9a */
    7,    /* freqval=a9b */
    7,    /* freqval=a9c */
    7,    /* freqval=a9d */
    7,    /* freqval=a9e */
    7,    /* freqval=a9f */
    7,    /* freqval=aa0 */
    7,    /* freqval=aa1 */
    7,    /* freqval=aa2 */
    7,    /* freqval=aa3 */
    7,    /* freqval=aa4 */
    7,    /* freqval=aa5 */
    7,    /* freqval=aa6 */
    7,    /* freqval=aa7 */
    7,    /* freqval=aa8 */
    7,    /* freqval=aa9 */
    7,    /* freqval=aaa */
    7,    /* freqval=aab */
    7,    /* freqval=aac */
    7,    /* freqval=aad */
    6,    /* freqval=aae */
    6,    /* freqval=aaf */
    6,    /* freqval=ab0 */
    6,    /* freqval=ab1 */
    6,    /* freqval=ab2 */
    6,    /* freqval=ab3 */
    6,    /* freqval=ab4 */
    6,    /* freqval=ab5 */
    6,    /* freqval=ab6 */
    6,    /* freqval=ab7 */
    6,    /* freqval=ab8 */
    6,    /* freqval=ab9 */
    6,    /* freqval=aba */
    6,    /* freqval=abb */
    6,    /* freqval=abc */
    6,    /* freqval=abd */
    6,    /* freqval=abe */
    6,    /* freqval=abf */
    6,    /* freqval=ac0 */
    6,    /* freqval=ac1 */
    6,    /* freqval=ac2 */
    6,    /* freqval=ac3 */
    6,    /* freqval=ac4 */
    6,    /* freqval=ac5 */
    6,    /* freqval=ac6 */
    6,    /* freqval=ac7 */
    6,    /* freqval=ac8 */
    6,    /* freqval=ac9 */
    6,    /* freqval=aca */
    6,    /* freqval=acb */
    6,    /* freqval=acc */
    6,    /* freqval=acd */
    6,    /* freqval=ace */
    6,    /* freqval=acf */
    6,    /* freqval=ad0 */
    6,    /* freqval=ad1 */
    6,    /* freqval=ad2 */
    6,    /* freqval=ad3 */
    6,    /* freqval=ad4 */
    6,    /* freqval=ad5 */
    6,    /* freqval=ad6 */
    6,    /* freqval=ad7 */
    6,    /* freqval=ad8 */
    6,    /* freqval=ad9 */
    6,    /* freqval=ada */
    6,    /* freqval=adb */
    6,    /* freqval=adc */
    6,    /* freqval=add */
    6,    /* freqval=ade */
    6,    /* freqval=adf */
    6,    /* freqval=ae0 */
    6,    /* freqval=ae1 */
    6,    /* freqval=ae2 */
    6,    /* freqval=ae3 */
    6,    /* freqval=ae4 */
    6,    /* freqval=ae5 */
    6,    /* freqval=ae6 */
    6,    /* freqval=ae7 */
    6,    /* freqval=ae8 */
    6,    /* freqval=ae9 */
    6,    /* freqval=aea */
    6,    /* freqval=aeb */
    6,    /* freqval=aec */
    6,    /* freqval=aed */
    6,    /* freqval=aee */
    6,    /* freqval=aef */
    6,    /* freqval=af0 */
    6,    /* freqval=af1 */
    6,    /* freqval=af2 */
    6,    /* freqval=af3 */
    6,    /* freqval=af4 */
    6,    /* freqval=af5 */
    6,    /* freqval=af6 */
    6,    /* freqval=af7 */
    6,    /* freqval=af8 */
    6,    /* freqval=af9 */
    6,    /* freqval=afa */
    6,    /* freqval=afb */
    6,    /* freqval=afc */
    6,    /* freqval=afd */
    6,    /* freqval=afe */
    6,    /* freqval=aff */
    6,    /* freqval=b00 */
    6,    /* freqval=b01 */
    6,    /* freqval=b02 */
    6,    /* freqval=b03 */
    6,    /* freqval=b04 */
    6,    /* freqval=b05 */
    6,    /* freqval=b06 */
    6,    /* freqval=b07 */
    6,    /* freqval=b08 */
    6,    /* freqval=b09 */
    6,    /* freqval=b0a */
    6,    /* freqval=b0b */
    6,    /* freqval=b0c */
    6,    /* freqval=b0d */
    6,    /* freqval=b0e */
    6,    /* freqval=b0f */
    6,    /* freqval=b10 */
    6,    /* freqval=b11 */
    6,    /* freqval=b12 */
    6,    /* freqval=b13 */
    6,    /* freqval=b14 */
    6,    /* freqval=b15 */
    6,    /* freqval=b16 */
    6,    /* freqval=b17 */
    6,    /* freqval=b18 */
    6,    /* freqval=b19 */
    6,    /* freqval=b1a */
    6,    /* freqval=b1b */
    6,    /* freqval=b1c */
    6,    /* freqval=b1d */
    6,    /* freqval=b1e */
    6,    /* freqval=b1f */
    6,    /* freqval=b20 */
    6,    /* freqval=b21 */
    6,    /* freqval=b22 */
    6,    /* freqval=b23 */
    6,    /* freqval=b24 */
    6,    /* freqval=b25 */
    6,    /* freqval=b26 */
    6,    /* freqval=b27 */
    6,    /* freqval=b28 */
    6,    /* freqval=b29 */
    6,    /* freqval=b2a */
    6,    /* freqval=b2b */
    6,    /* freqval=b2c */
    6,    /* freqval=b2d */
    6,    /* freqval=b2e */
    6,    /* freqval=b2f */
    6,    /* freqval=b30 */
    6,    /* freqval=b31 */
    6,    /* freqval=b32 */
    6,    /* freqval=b33 */
    6,    /* freqval=b34 */
    6,    /* freqval=b35 */
    6,    /* freqval=b36 */
    6,    /* freqval=b37 */
    6,    /* freqval=b38 */
    6,    /* freqval=b39 */
    6,    /* freqval=b3a */
    6,    /* freqval=b3b */
    6,    /* freqval=b3c */
    6,    /* freqval=b3d */
    6,    /* freqval=b3e */
    6,    /* freqval=b3f */
    6,    /* freqval=b40 */
    6,    /* freqval=b41 */
    6,    /* freqval=b42 */
    6,    /* freqval=b43 */
    6,    /* freqval=b44 */
    6,    /* freqval=b45 */
    6,    /* freqval=b46 */
    6,    /* freqval=b47 */
    6,    /* freqval=b48 */
    6,    /* freqval=b49 */
    6,    /* freqval=b4a */
    6,    /* freqval=b4b */
    6,    /* freqval=b4c */
    6,    /* freqval=b4d */
    6,    /* freqval=b4e */
    6,    /* freqval=b4f */
    5,    /* freqval=b50 */
    5,    /* freqval=b51 */
    5,    /* freqval=b52 */
    5,    /* freqval=b53 */
    5,    /* freqval=b54 */
    5,    /* freqval=b55 */
    5,    /* freqval=b56 */
    5,    /* freqval=b57 */
    5,    /* freqval=b58 */
    5,    /* freqval=b59 */
    5,    /* freqval=b5a */
    5,    /* freqval=b5b */
    5,    /* freqval=b5c */
    5,    /* freqval=b5d */
    5,    /* freqval=b5e */
    5,    /* freqval=b5f */
    5,    /* freqval=b60 */
    5,    /* freqval=b61 */
    5,    /* freqval=b62 */
    5,    /* freqval=b63 */
    5,    /* freqval=b64 */
    5,    /* freqval=b65 */
    5,    /* freqval=b66 */
    5,    /* freqval=b67 */
    5,    /* freqval=b68 */
    5,    /* freqval=b69 */
    5,    /* freqval=b6a */
    5,    /* freqval=b6b */
    5,    /* freqval=b6c */
    5,    /* freqval=b6d */
    5,    /* freqval=b6e */
    5,    /* freqval=b6f */
    5,    /* freqval=b70 */
    5,    /* freqval=b71 */
    5,    /* freqval=b72 */
    5,    /* freqval=b73 */
    5,    /* freqval=b74 */
    5,    /* freqval=b75 */
    5,    /* freqval=b76 */
    5,    /* freqval=b77 */
    5,    /* freqval=b78 */
    5,    /* freqval=b79 */
    5,    /* freqval=b7a */
    5,    /* freqval=b7b */
    5,    /* freqval=b7c */
    5,    /* freqval=b7d */
    5,    /* freqval=b7e */
    5,    /* freqval=b7f */
    5,    /* freqval=b80 */
    5,    /* freqval=b81 */
    5,    /* freqval=b82 */
    5,    /* freqval=b83 */
    5,    /* freqval=b84 */
    5,    /* freqval=b85 */
    5,    /* freqval=b86 */
    5,    /* freqval=b87 */
    5,    /* freqval=b88 */
    5,    /* freqval=b89 */
    5,    /* freqval=b8a */
    5,    /* freqval=b8b */
    5,    /* freqval=b8c */
    5,    /* freqval=b8d */
    5,    /* freqval=b8e */
    5,    /* freqval=b8f */
    5,    /* freqval=b90 */
    5,    /* freqval=b91 */
    5,    /* freqval=b92 */
    5,    /* freqval=b93 */
    5,    /* freqval=b94 */
    5,    /* freqval=b95 */
    5,    /* freqval=b96 */
    5,    /* freqval=b97 */
    5,    /* freqval=b98 */
    5,    /* freqval=b99 */
    5,    /* freqval=b9a */
    5,    /* freqval=b9b */
    5,    /* freqval=b9c */
    5,    /* freqval=b9d */
    5,    /* freqval=b9e */
    5,    /* freqval=b9f */
    5,    /* freqval=ba0 */
    5,    /* freqval=ba1 */
    5,    /* freqval=ba2 */
    5,    /* freqval=ba3 */
    5,    /* freqval=ba4 */
    5,    /* freqval=ba5 */
    5,    /* freqval=ba6 */
    5,    /* freqval=ba7 */
    5,    /* freqval=ba8 */
    5,    /* freqval=ba9 */
    5,    /* freqval=baa */
    5,    /* freqval=bab */
    5,    /* freqval=bac */
    5,    /* freqval=bad */
    5,    /* freqval=bae */
    5,    /* freqval=baf */
    5,    /* freqval=bb0 */
    5,    /* freqval=bb1 */
    5,    /* freqval=bb2 */
    5,    /* freqval=bb3 */
    5,    /* freqval=bb4 */
    5,    /* freqval=bb5 */
    5,    /* freqval=bb6 */
    5,    /* freqval=bb7 */
    5,    /* freqval=bb8 */
    5,    /* freqval=bb9 */
    5,    /* freqval=bba */
    5,    /* freqval=bbb */
    5,    /* freqval=bbc */
    5,    /* freqval=bbd */
    5,    /* freqval=bbe */
    5,    /* freqval=bbf */
    5,    /* freqval=bc0 */
    5,    /* freqval=bc1 */
    5,    /* freqval=bc2 */
    5,    /* freqval=bc3 */
    5,    /* freqval=bc4 */
    5,    /* freqval=bc5 */
    5,    /* freqval=bc6 */
    5,    /* freqval=bc7 */
    5,    /* freqval=bc8 */
    5,    /* freqval=bc9 */
    5,    /* freqval=bca */
    5,    /* freqval=bcb */
    5,    /* freqval=bcc */
    5,    /* freqval=bcd */
    5,    /* freqval=bce */
    5,    /* freqval=bcf */
    5,    /* freqval=bd0 */
    5,    /* freqval=bd1 */
    5,    /* freqval=bd2 */
    5,    /* freqval=bd3 */
    5,    /* freqval=bd4 */
    5,    /* freqval=bd5 */
    5,    /* freqval=bd6 */
    5,    /* freqval=bd7 */
    5,    /* freqval=bd8 */
    5,    /* freqval=bd9 */
    5,    /* freqval=bda */
    5,    /* freqval=bdb */
    5,    /* freqval=bdc */
    5,    /* freqval=bdd */
    5,    /* freqval=bde */
    5,    /* freqval=bdf */
    5,    /* freqval=be0 */
    5,    /* freqval=be1 */
    5,    /* freqval=be2 */
    5,    /* freqval=be3 */
    5,    /* freqval=be4 */
    5,    /* freqval=be5 */
    5,    /* freqval=be6 */
    5,    /* freqval=be7 */
    5,    /* freqval=be8 */
    5,    /* freqval=be9 */
    5,    /* freqval=bea */
    5,    /* freqval=beb */
    5,    /* freqval=bec */
    5,    /* freqval=bed */
    5,    /* freqval=bee */
    5,    /* freqval=bef */
    5,    /* freqval=bf0 */
    5,    /* freqval=bf1 */
    5,    /* freqval=bf2 */
    5,    /* freqval=bf3 */
    5,    /* freqval=bf4 */
    5,    /* freqval=bf5 */
    5,    /* freqval=bf6 */
    5,    /* freqval=bf7 */
    5,    /* freqval=bf8 */
    5,    /* freqval=bf9 */
    5,    /* freqval=bfa */
    5,    /* freqval=bfb */
    4,    /* freqval=bfc */
    4,    /* freqval=bfd */
    4,    /* freqval=bfe */
    4,    /* freqval=bff */
    4,    /* freqval=c00 */
    4,    /* freqval=c01 */
    4,    /* freqval=c02 */
    4,    /* freqval=c03 */
    4,    /* freqval=c04 */
    4,    /* freqval=c05 */
    4,    /* freqval=c06 */
    4,    /* freqval=c07 */
    4,    /* freqval=c08 */
    4,    /* freqval=c09 */
    4,    /* freqval=c0a */
    4,    /* freqval=c0b */
    4,    /* freqval=c0c */
    4,    /* freqval=c0d */
    4,    /* freqval=c0e */
    4,    /* freqval=c0f */
    4,    /* freqval=c10 */
    4,    /* freqval=c11 */
    4,    /* freqval=c12 */
    4,    /* freqval=c13 */
    4,    /* freqval=c14 */
    4,    /* freqval=c15 */
    4,    /* freqval=c16 */
    4,    /* freqval=c17 */
    4,    /* freqval=c18 */
    4,    /* freqval=c19 */
    4,    /* freqval=c1a */
    4,    /* freqval=c1b */
    4,    /* freqval=c1c */
    4,    /* freqval=c1d */
    4,    /* freqval=c1e */
    4,    /* freqval=c1f */
    4,    /* freqval=c20 */
    4,    /* freqval=c21 */
    4,    /* freqval=c22 */
    4,    /* freqval=c23 */
    4,    /* freqval=c24 */
    4,    /* freqval=c25 */
    4,    /* freqval=c26 */
    4,    /* freqval=c27 */
    4,    /* freqval=c28 */
    4,    /* freqval=c29 */
    4,    /* freqval=c2a */
    4,    /* freqval=c2b */
    4,    /* freqval=c2c */
    4,    /* freqval=c2d */
    4,    /* freqval=c2e */
    4,    /* freqval=c2f */
    4,    /* freqval=c30 */
    4,    /* freqval=c31 */
    4,    /* freqval=c32 */
    4,    /* freqval=c33 */
    4,    /* freqval=c34 */
    4,    /* freqval=c35 */
    4,    /* freqval=c36 */
    4,    /* freqval=c37 */
    4,    /* freqval=c38 */
    4,    /* freqval=c39 */
    4,    /* freqval=c3a */
    4,    /* freqval=c3b */
    4,    /* freqval=c3c */
    4,    /* freqval=c3d */
    4,    /* freqval=c3e */
    4,    /* freqval=c3f */
    4,    /* freqval=c40 */
    4,    /* freqval=c41 */
    4,    /* freqval=c42 */
    4,    /* freqval=c43 */
    4,    /* freqval=c44 */
    4,    /* freqval=c45 */
    4,    /* freqval=c46 */
    4,    /* freqval=c47 */
    4,    /* freqval=c48 */
    4,    /* freqval=c49 */
    4,    /* freqval=c4a */
    4,    /* freqval=c4b */
    4,    /* freqval=c4c */
    4,    /* freqval=c4d */
    4,    /* freqval=c4e */
    4,    /* freqval=c4f */
    4,    /* freqval=c50 */
    4,    /* freqval=c51 */
    4,    /* freqval=c52 */
    4,    /* freqval=c53 */
    4,    /* freqval=c54 */
    4,    /* freqval=c55 */
    4,    /* freqval=c56 */
    4,    /* freqval=c57 */
    4,    /* freqval=c58 */
    4,    /* freqval=c59 */
    4,    /* freqval=c5a */
    4,    /* freqval=c5b */
    4,    /* freqval=c5c */
    4,    /* freqval=c5d */
    4,    /* freqval=c5e */
    4,    /* freqval=c5f */
    4,    /* freqval=c60 */
    4,    /* freqval=c61 */
    4,    /* freqval=c62 */
    4,    /* freqval=c63 */
    4,    /* freqval=c64 */
    4,    /* freqval=c65 */
    4,    /* freqval=c66 */
    4,    /* freqval=c67 */
    4,    /* freqval=c68 */
    4,    /* freqval=c69 */
    4,    /* freqval=c6a */
    4,    /* freqval=c6b */
    4,    /* freqval=c6c */
    4,    /* freqval=c6d */
    4,    /* freqval=c6e */
    4,    /* freqval=c6f */
    4,    /* freqval=c70 */
    4,    /* freqval=c71 */
    4,    /* freqval=c72 */
    4,    /* freqval=c73 */
    4,    /* freqval=c74 */
    4,    /* freqval=c75 */
    4,    /* freqval=c76 */
    4,    /* freqval=c77 */
    4,    /* freqval=c78 */
    4,    /* freqval=c79 */
    4,    /* freqval=c7a */
    4,    /* freqval=c7b */
    4,    /* freqval=c7c */
    4,    /* freqval=c7d */
    4,    /* freqval=c7e */
    4,    /* freqval=c7f */
    4,    /* freqval=c80 */
    4,    /* freqval=c81 */
    4,    /* freqval=c82 */
    4,    /* freqval=c83 */
    4,    /* freqval=c84 */
    4,    /* freqval=c85 */
    4,    /* freqval=c86 */
    4,    /* freqval=c87 */
    4,    /* freqval=c88 */
    4,    /* freqval=c89 */
    4,    /* freqval=c8a */
    4,    /* freqval=c8b */
    4,    /* freqval=c8c */
    4,    /* freqval=c8d */
    4,    /* freqval=c8e */
    4,    /* freqval=c8f */
    4,    /* freqval=c90 */
    4,    /* freqval=c91 */
    4,    /* freqval=c92 */
    4,    /* freqval=c93 */
    4,    /* freqval=c94 */
    4,    /* freqval=c95 */
    4,    /* freqval=c96 */
    4,    /* freqval=c97 */
    4,    /* freqval=c98 */
    4,    /* freqval=c99 */
    4,    /* freqval=c9a */
    4,    /* freqval=c9b */
    4,    /* freqval=c9c */
    4,    /* freqval=c9d */
    4,    /* freqval=c9e */
    4,    /* freqval=c9f */
    4,    /* freqval=ca0 */
    4,    /* freqval=ca1 */
    4,    /* freqval=ca2 */
    4,    /* freqval=ca3 */
    4,    /* freqval=ca4 */
    4,    /* freqval=ca5 */
    4,    /* freqval=ca6 */
    4,    /* freqval=ca7 */
    4,    /* freqval=ca8 */
    4,    /* freqval=ca9 */
    4,    /* freqval=caa */
    4,    /* freqval=cab */
    4,    /* freqval=cac */
    4,    /* freqval=cad */
    4,    /* freqval=cae */
    4,    /* freqval=caf */
    4,    /* freqval=cb0 */
    4,    /* freqval=cb1 */
    4,    /* freqval=cb2 */
    3,    /* freqval=cb3 */
    3,    /* freqval=cb4 */
    3,    /* freqval=cb5 */
    3,    /* freqval=cb6 */
    3,    /* freqval=cb7 */
    3,    /* freqval=cb8 */
    3,    /* freqval=cb9 */
    3,    /* freqval=cba */
    3,    /* freqval=cbb */
    3,    /* freqval=cbc */
    3,    /* freqval=cbd */
    3,    /* freqval=cbe */
    3,    /* freqval=cbf */
    3,    /* freqval=cc0 */
    3,    /* freqval=cc1 */
    3,    /* freqval=cc2 */
    3,    /* freqval=cc3 */
    3,    /* freqval=cc4 */
    3,    /* freqval=cc5 */
    3,    /* freqval=cc6 */
    3,    /* freqval=cc7 */
    3,    /* freqval=cc8 */
    3,    /* freqval=cc9 */
    3,    /* freqval=cca */
    3,    /* freqval=ccb */
    3,    /* freqval=ccc */
    3,    /* freqval=ccd */
    3,    /* freqval=cce */
    3,    /* freqval=ccf */
    3,    /* freqval=cd0 */
    3,    /* freqval=cd1 */
    3,    /* freqval=cd2 */
    3,    /* freqval=cd3 */
    3,    /* freqval=cd4 */
    3,    /* freqval=cd5 */
    3,    /* freqval=cd6 */
    3,    /* freqval=cd7 */
    3,    /* freqval=cd8 */
    3,    /* freqval=cd9 */
    3,    /* freqval=cda */
    3,    /* freqval=cdb */
    3,    /* freqval=cdc */
    3,    /* freqval=cdd */
    3,    /* freqval=cde */
    3,    /* freqval=cdf */
    3,    /* freqval=ce0 */
    3,    /* freqval=ce1 */
    3,    /* freqval=ce2 */
    3,    /* freqval=ce3 */
    3,    /* freqval=ce4 */
    3,    /* freqval=ce5 */
    3,    /* freqval=ce6 */
    3,    /* freqval=ce7 */
    3,    /* freqval=ce8 */
    3,    /* freqval=ce9 */
    3,    /* freqval=cea */
    3,    /* freqval=ceb */
    3,    /* freqval=cec */
    3,    /* freqval=ced */
    3,    /* freqval=cee */
    3,    /* freqval=cef */
    3,    /* freqval=cf0 */
    3,    /* freqval=cf1 */
    3,    /* freqval=cf2 */
    3,    /* freqval=cf3 */
    3,    /* freqval=cf4 */
    3,    /* freqval=cf5 */
    3,    /* freqval=cf6 */
    3,    /* freqval=cf7 */
    3,    /* freqval=cf8 */
    3,    /* freqval=cf9 */
    3,    /* freqval=cfa */
    3,    /* freqval=cfb */
    3,    /* freqval=cfc */
    3,    /* freqval=cfd */
    3,    /* freqval=cfe */
    3,    /* freqval=cff */
    3,    /* freqval=d00 */
    3,    /* freqval=d01 */
    3,    /* freqval=d02 */
    3,    /* freqval=d03 */
    3,    /* freqval=d04 */
    3,    /* freqval=d05 */
    3,    /* freqval=d06 */
    3,    /* freqval=d07 */
    3,    /* freqval=d08 */
    3,    /* freqval=d09 */
    3,    /* freqval=d0a */
    3,    /* freqval=d0b */
    3,    /* freqval=d0c */
    3,    /* freqval=d0d */
    3,    /* freqval=d0e */
    3,    /* freqval=d0f */
    3,    /* freqval=d10 */
    3,    /* freqval=d11 */
    3,    /* freqval=d12 */
    3,    /* freqval=d13 */
    3,    /* freqval=d14 */
    3,    /* freqval=d15 */
    3,    /* freqval=d16 */
    3,    /* freqval=d17 */
    3,    /* freqval=d18 */
    3,    /* freqval=d19 */
    3,    /* freqval=d1a */
    3,    /* freqval=d1b */
    3,    /* freqval=d1c */
    3,    /* freqval=d1d */
    3,    /* freqval=d1e */
    3,    /* freqval=d1f */
    3,    /* freqval=d20 */
    3,    /* freqval=d21 */
    3,    /* freqval=d22 */
    3,    /* freqval=d23 */
    3,    /* freqval=d24 */
    3,    /* freqval=d25 */
    3,    /* freqval=d26 */
    3,    /* freqval=d27 */
    3,    /* freqval=d28 */
    3,    /* freqval=d29 */
    3,    /* freqval=d2a */
    3,    /* freqval=d2b */
    3,    /* freqval=d2c */
    3,    /* freqval=d2d */
    3,    /* freqval=d2e */
    3,    /* freqval=d2f */
    3,    /* freqval=d30 */
    3,    /* freqval=d31 */
    3,    /* freqval=d32 */
    3,    /* freqval=d33 */
    3,    /* freqval=d34 */
    3,    /* freqval=d35 */
    3,    /* freqval=d36 */
    3,    /* freqval=d37 */
    3,    /* freqval=d38 */
    3,    /* freqval=d39 */
    3,    /* freqval=d3a */
    3,    /* freqval=d3b */
    3,    /* freqval=d3c */
    3,    /* freqval=d3d */
    3,    /* freqval=d3e */
    3,    /* freqval=d3f */
    3,    /* freqval=d40 */
    3,    /* freqval=d41 */
    3,    /* freqval=d42 */
    3,    /* freqval=d43 */
    3,    /* freqval=d44 */
    3,    /* freqval=d45 */
    3,    /* freqval=d46 */
    3,    /* freqval=d47 */
    3,    /* freqval=d48 */
    3,    /* freqval=d49 */
    3,    /* freqval=d4a */
    3,    /* freqval=d4b */
    3,    /* freqval=d4c */
    3,    /* freqval=d4d */
    3,    /* freqval=d4e */
    3,    /* freqval=d4f */
    3,    /* freqval=d50 */
    3,    /* freqval=d51 */
    3,    /* freqval=d52 */
    3,    /* freqval=d53 */
    3,    /* freqval=d54 */
    3,    /* freqval=d55 */
    3,    /* freqval=d56 */
    3,    /* freqval=d57 */
    3,    /* freqval=d58 */
    3,    /* freqval=d59 */
    3,    /* freqval=d5a */
    3,    /* freqval=d5b */
    3,    /* freqval=d5c */
    3,    /* freqval=d5d */
    3,    /* freqval=d5e */
    3,    /* freqval=d5f */
    3,    /* freqval=d60 */
    3,    /* freqval=d61 */
    3,    /* freqval=d62 */
    3,    /* freqval=d63 */
    3,    /* freqval=d64 */
    3,    /* freqval=d65 */
    3,    /* freqval=d66 */
    3,    /* freqval=d67 */
    3,    /* freqval=d68 */
    3,    /* freqval=d69 */
    3,    /* freqval=d6a */
    3,    /* freqval=d6b */
    3,    /* freqval=d6c */
    3,    /* freqval=d6d */
    3,    /* freqval=d6e */
    3,    /* freqval=d6f */
    3,    /* freqval=d70 */
    3,    /* freqval=d71 */
    3,    /* freqval=d72 */
    3,    /* freqval=d73 */
    2,    /* freqval=d74 */
    2,    /* freqval=d75 */
    2,    /* freqval=d76 */
    2,    /* freqval=d77 */
    2,    /* freqval=d78 */
    2,    /* freqval=d79 */
    2,    /* freqval=d7a */
    2,    /* freqval=d7b */
    2,    /* freqval=d7c */
    2,    /* freqval=d7d */
    2,    /* freqval=d7e */
    2,    /* freqval=d7f */
    2,    /* freqval=d80 */
    2,    /* freqval=d81 */
    2,    /* freqval=d82 */
    2,    /* freqval=d83 */
    2,    /* freqval=d84 */
    2,    /* freqval=d85 */
    2,    /* freqval=d86 */
    2,    /* freqval=d87 */
    2,    /* freqval=d88 */
    2,    /* freqval=d89 */
    2,    /* freqval=d8a */
    2,    /* freqval=d8b */
    2,    /* freqval=d8c */
    2,    /* freqval=d8d */
    2,    /* freqval=d8e */
    2,    /* freqval=d8f */
    2,    /* freqval=d90 */
    2,    /* freqval=d91 */
    2,    /* freqval=d92 */
    2,    /* freqval=d93 */
    2,    /* freqval=d94 */
    2,    /* freqval=d95 */
    2,    /* freqval=d96 */
    2,    /* freqval=d97 */
    2,    /* freqval=d98 */
    2,    /* freqval=d99 */
    2,    /* freqval=d9a */
    2,    /* freqval=d9b */
    2,    /* freqval=d9c */
    2,    /* freqval=d9d */
    2,    /* freqval=d9e */
    2,    /* freqval=d9f */
    2,    /* freqval=da0 */
    2,    /* freqval=da1 */
    2,    /* freqval=da2 */
    2,    /* freqval=da3 */
    2,    /* freqval=da4 */
    2,    /* freqval=da5 */
    2,    /* freqval=da6 */
    2,    /* freqval=da7 */
    2,    /* freqval=da8 */
    2,    /* freqval=da9 */
    2,    /* freqval=daa */
    2,    /* freqval=dab */
    2,    /* freqval=dac */
    2,    /* freqval=dad */
    2,    /* freqval=dae */
    2,    /* freqval=daf */
    2,    /* freqval=db0 */
    2,    /* freqval=db1 */
    2,    /* freqval=db2 */
    2,    /* freqval=db3 */
    2,    /* freqval=db4 */
    2,    /* freqval=db5 */
    2,    /* freqval=db6 */
    2,    /* freqval=db7 */
    2,    /* freqval=db8 */
    2,    /* freqval=db9 */
    2,    /* freqval=dba */
    2,    /* freqval=dbb */
    2,    /* freqval=dbc */
    2,    /* freqval=dbd */
    2,    /* freqval=dbe */
    2,    /* freqval=dbf */
    2,    /* freqval=dc0 */
    2,    /* freqval=dc1 */
    2,    /* freqval=dc2 */
    2,    /* freqval=dc3 */
    2,    /* freqval=dc4 */
    2,    /* freqval=dc5 */
    2,    /* freqval=dc6 */
    2,    /* freqval=dc7 */
    2,    /* freqval=dc8 */
    2,    /* freqval=dc9 */
    2,    /* freqval=dca */
    2,    /* freqval=dcb */
    2,    /* freqval=dcc */
    2,    /* freqval=dcd */
    2,    /* freqval=dce */
    2,    /* freqval=dcf */
    2,    /* freqval=dd0 */
    2,    /* freqval=dd1 */
    2,    /* freqval=dd2 */
    2,    /* freqval=dd3 */
    2,    /* freqval=dd4 */
    2,    /* freqval=dd5 */
    2,    /* freqval=dd6 */
    2,    /* freqval=dd7 */
    2,    /* freqval=dd8 */
    2,    /* freqval=dd9 */
    2,    /* freqval=dda */
    2,    /* freqval=ddb */
    2,    /* freqval=ddc */
    2,    /* freqval=ddd */
    2,    /* freqval=dde */
    2,    /* freqval=ddf */
    2,    /* freqval=de0 */
    2,    /* freqval=de1 */
    2,    /* freqval=de2 */
    2,    /* freqval=de3 */
    2,    /* freqval=de4 */
    2,    /* freqval=de5 */
    2,    /* freqval=de6 */
    2,    /* freqval=de7 */
    2,    /* freqval=de8 */
    2,    /* freqval=de9 */
    2,    /* freqval=dea */
    2,    /* freqval=deb */
    2,    /* freqval=dec */
    2,    /* freqval=ded */
    2,    /* freqval=dee */
    2,    /* freqval=def */
    2,    /* freqval=df0 */
    2,    /* freqval=df1 */
    2,    /* freqval=df2 */
    2,    /* freqval=df3 */
    2,    /* freqval=df4 */
    2,    /* freqval=df5 */
    2,    /* freqval=df6 */
    2,    /* freqval=df7 */
    2,    /* freqval=df8 */
    2,    /* freqval=df9 */
    2,    /* freqval=dfa */
    2,    /* freqval=dfb */
    2,    /* freqval=dfc */
    2,    /* freqval=dfd */
    2,    /* freqval=dfe */
    2,    /* freqval=dff */
    2,    /* freqval=e00 */
    2,    /* freqval=e01 */
    2,    /* freqval=e02 */
    2,    /* freqval=e03 */
    2,    /* freqval=e04 */
    2,    /* freqval=e05 */
    2,    /* freqval=e06 */
    2,    /* freqval=e07 */
    2,    /* freqval=e08 */
    2,    /* freqval=e09 */
    2,    /* freqval=e0a */
    2,    /* freqval=e0b */
    2,    /* freqval=e0c */
    2,    /* freqval=e0d */
    2,    /* freqval=e0e */
    2,    /* freqval=e0f */
    2,    /* freqval=e10 */
    2,    /* freqval=e11 */
    2,    /* freqval=e12 */
    2,    /* freqval=e13 */
    2,    /* freqval=e14 */
    2,    /* freqval=e15 */
    2,    /* freqval=e16 */
    2,    /* freqval=e17 */
    2,    /* freqval=e18 */
    2,    /* freqval=e19 */
    2,    /* freqval=e1a */
    2,    /* freqval=e1b */
    2,    /* freqval=e1c */
    2,    /* freqval=e1d */
    2,    /* freqval=e1e */
    2,    /* freqval=e1f */
    2,    /* freqval=e20 */
    2,    /* freqval=e21 */
    2,    /* freqval=e22 */
    2,    /* freqval=e23 */
    2,    /* freqval=e24 */
    2,    /* freqval=e25 */
    2,    /* freqval=e26 */
    2,    /* freqval=e27 */
    2,    /* freqval=e28 */
    2,    /* freqval=e29 */
    2,    /* freqval=e2a */
    2,    /* freqval=e2b */
    2,    /* freqval=e2c */
    2,    /* freqval=e2d */
    2,    /* freqval=e2e */
    2,    /* freqval=e2f */
    2,    /* freqval=e30 */
    2,    /* freqval=e31 */
    2,    /* freqval=e32 */
    2,    /* freqval=e33 */
    2,    /* freqval=e34 */
    2,    /* freqval=e35 */
    2,    /* freqval=e36 */
    2,    /* freqval=e37 */
    2,    /* freqval=e38 */
    2,    /* freqval=e39 */
    2,    /* freqval=e3a */
    2,    /* freqval=e3b */
    2,    /* freqval=e3c */
    2,    /* freqval=e3d */
    2,    /* freqval=e3e */
    2,    /* freqval=e3f */
    2,    /* freqval=e40 */
    1,    /* freqval=e41 */
    1,    /* freqval=e42 */
    1,    /* freqval=e43 */
    1,    /* freqval=e44 */
    1,    /* freqval=e45 */
    1,    /* freqval=e46 */
    1,    /* freqval=e47 */
    1,    /* freqval=e48 */
    1,    /* freqval=e49 */
    1,    /* freqval=e4a */
    1,    /* freqval=e4b */
    1,    /* freqval=e4c */
    1,    /* freqval=e4d */
    1,    /* freqval=e4e */
    1,    /* freqval=e4f */
    1,    /* freqval=e50 */
    1,    /* freqval=e51 */
    1,    /* freqval=e52 */
    1,    /* freqval=e53 */
    1,    /* freqval=e54 */
    1,    /* freqval=e55 */
    1,    /* freqval=e56 */
    1,    /* freqval=e57 */
    1,    /* freqval=e58 */
    1,    /* freqval=e59 */
    1,    /* freqval=e5a */
    1,    /* freqval=e5b */
    1,    /* freqval=e5c */
    1,    /* freqval=e5d */
    1,    /* freqval=e5e */
    1,    /* freqval=e5f */
    1,    /* freqval=e60 */
    1,    /* freqval=e61 */
    1,    /* freqval=e62 */
    1,    /* freqval=e63 */
    1,    /* freqval=e64 */
    1,    /* freqval=e65 */
    1,    /* freqval=e66 */
    1,    /* freqval=e67 */
    1,    /* freqval=e68 */
    1,    /* freqval=e69 */
    1,    /* freqval=e6a */
    1,    /* freqval=e6b */
    1,    /* freqval=e6c */
    1,    /* freqval=e6d */
    1,    /* freqval=e6e */
    1,    /* freqval=e6f */
    1,    /* freqval=e70 */
    1,    /* freqval=e71 */
    1,    /* freqval=e72 */
    1,    /* freqval=e73 */
    1,    /* freqval=e74 */
    1,    /* freqval=e75 */
    1,    /* freqval=e76 */
    1,    /* freqval=e77 */
    1,    /* freqval=e78 */
    1,    /* freqval=e79 */
    1,    /* freqval=e7a */
    1,    /* freqval=e7b */
    1,    /* freqval=e7c */
    1,    /* freqval=e7d */
    1,    /* freqval=e7e */
    1,    /* freqval=e7f */
    1,    /* freqval=e80 */
    1,    /* freqval=e81 */
    1,    /* freqval=e82 */
    1,    /* freqval=e83 */
    1,    /* freqval=e84 */
    1,    /* freqval=e85 */
    1,    /* freqval=e86 */
    1,    /* freqval=e87 */
    1,    /* freqval=e88 */
    1,    /* freqval=e89 */
    1,    /* freqval=e8a */
    1,    /* freqval=e8b */
    1,    /* freqval=e8c */
    1,    /* freqval=e8d */
    1,    /* freqval=e8e */
    1,    /* freqval=e8f */
    1,    /* freqval=e90 */
    1,    /* freqval=e91 */
    1,    /* freqval=e92 */
    1,    /* freqval=e93 */
    1,    /* freqval=e94 */
    1,    /* freqval=e95 */
    1,    /* freqval=e96 */
    1,    /* freqval=e97 */
    1,    /* freqval=e98 */
    1,    /* freqval=e99 */
    1,    /* freqval=e9a */
    1,    /* freqval=e9b */
    1,    /* freqval=e9c */
    1,    /* freqval=e9d */
    1,    /* freqval=e9e */
    1,    /* freqval=e9f */
    1,    /* freqval=ea0 */
    1,    /* freqval=ea1 */
    1,    /* freqval=ea2 */
    1,    /* freqval=ea3 */
    1,    /* freqval=ea4 */
    1,    /* freqval=ea5 */
    1,    /* freqval=ea6 */
    1,    /* freqval=ea7 */
    1,    /* freqval=ea8 */
    1,    /* freqval=ea9 */
    1,    /* freqval=eaa */
    1,    /* freqval=eab */
    1,    /* freqval=eac */
    1,    /* freqval=ead */
    1,    /* freqval=eae */
    1,    /* freqval=eaf */
    1,    /* freqval=eb0 */
    1,    /* freqval=eb1 */
    1,    /* freqval=eb2 */
    1,    /* freqval=eb3 */
    1,    /* freqval=eb4 */
    1,    /* freqval=eb5 */
    1,    /* freqval=eb6 */
    1,    /* freqval=eb7 */
    1,    /* freqval=eb8 */
    1,    /* freqval=eb9 */
    1,    /* freqval=eba */
    1,    /* freqval=ebb */
    1,    /* freqval=ebc */
    1,    /* freqval=ebd */
    1,    /* freqval=ebe */
    1,    /* freqval=ebf */
    1,    /* freqval=ec0 */
    1,    /* freqval=ec1 */
    1,    /* freqval=ec2 */
    1,    /* freqval=ec3 */
    1,    /* freqval=ec4 */
    1,    /* freqval=ec5 */
    1,    /* freqval=ec6 */
    1,    /* freqval=ec7 */
    1,    /* freqval=ec8 */
    1,    /* freqval=ec9 */
    1,    /* freqval=eca */
    1,    /* freqval=ecb */
    1,    /* freqval=ecc */
    1,    /* freqval=ecd */
    1,    /* freqval=ece */
    1,    /* freqval=ecf */
    1,    /* freqval=ed0 */
    1,    /* freqval=ed1 */
    1,    /* freqval=ed2 */
    1,    /* freqval=ed3 */
    1,    /* freqval=ed4 */
    1,    /* freqval=ed5 */
    1,    /* freqval=ed6 */
    1,    /* freqval=ed7 */
    1,    /* freqval=ed8 */
    1,    /* freqval=ed9 */
    1,    /* freqval=eda */
    1,    /* freqval=edb */
    1,    /* freqval=edc */
    1,    /* freqval=edd */
    1,    /* freqval=ede */
    1,    /* freqval=edf */
    1,    /* freqval=ee0 */
    1,    /* freqval=ee1 */
    1,    /* freqval=ee2 */
    1,    /* freqval=ee3 */
    1,    /* freqval=ee4 */
    1,    /* freqval=ee5 */
    1,    /* freqval=ee6 */
    1,    /* freqval=ee7 */
    1,    /* freqval=ee8 */
    1,    /* freqval=ee9 */
    1,    /* freqval=eea */
    1,    /* freqval=eeb */
    1,    /* freqval=eec */
    1,    /* freqval=eed */
    1,    /* freqval=eee */
    1,    /* freqval=eef */
    1,    /* freqval=ef0 */
    1,    /* freqval=ef1 */
    1,    /* freqval=ef2 */
    1,    /* freqval=ef3 */
    1,    /* freqval=ef4 */
    1,    /* freqval=ef5 */
    1,    /* freqval=ef6 */
    1,    /* freqval=ef7 */
    1,    /* freqval=ef8 */
    1,    /* freqval=ef9 */
    1,    /* freqval=efa */
    1,    /* freqval=efb */
    1,    /* freqval=efc */
    1,    /* freqval=efd */
    1,    /* freqval=efe */
    1,    /* freqval=eff */
    1,    /* freqval=f00 */
    1,    /* freqval=f01 */
    1,    /* freqval=f02 */
    1,    /* freqval=f03 */
    1,    /* freqval=f04 */
    1,    /* freqval=f05 */
    1,    /* freqval=f06 */
    1,    /* freqval=f07 */
    1,    /* freqval=f08 */
    1,    /* freqval=f09 */
    1,    /* freqval=f0a */
    1,    /* freqval=f0b */
    1,    /* freqval=f0c */
    1,    /* freqval=f0d */
    1,    /* freqval=f0e */
    1,    /* freqval=f0f */
    1,    /* freqval=f10 */
    1,    /* freqval=f11 */
    1,    /* freqval=f12 */
    1,    /* freqval=f13 */
    1,    /* freqval=f14 */
    1,    /* freqval=f15 */
    1,    /* freqval=f16 */
    1,    /* freqval=f17 */
    1,    /* freqval=f18 */
    1,    /* freqval=f19 */
    0,    /* freqval=f1a */
    0,    /* freqval=f1b */
    0,    /* freqval=f1c */
    0,    /* freqval=f1d */
    0,    /* freqval=f1e */
    0,    /* freqval=f1f */
    0,    /* freqval=f20 */
    0,    /* freqval=f21 */
    0,    /* freqval=f22 */
    0,    /* freqval=f23 */
    0,    /* freqval=f24 */
    0,    /* freqval=f25 */
    0,    /* freqval=f26 */
    0,    /* freqval=f27 */
    0,    /* freqval=f28 */
    0,    /* freqval=f29 */
    0,    /* freqval=f2a */
    0,    /* freqval=f2b */
    0,    /* freqval=f2c */
    0,    /* freqval=f2d */
    0,    /* freqval=f2e */
    0,    /* freqval=f2f */
    0,    /* freqval=f30 */
    0,    /* freqval=f31 */
    0,    /* freqval=f32 */
    0,    /* freqval=f33 */
    0,    /* freqval=f34 */
    0,    /* freqval=f35 */
    0,    /* freqval=f36 */
    0,    /* freqval=f37 */
    0,    /* freqval=f38 */
    0,    /* freqval=f39 */
    0,    /* freqval=f3a */
    0,    /* freqval=f3b */
    0,    /* freqval=f3c */
    0,    /* freqval=f3d */
    0,    /* freqval=f3e */
    0,    /* freqval=f3f */
    0,    /* freqval=f40 */
    0,    /* freqval=f41 */
    0,    /* freqval=f42 */
    0,    /* freqval=f43 */
    0,    /* freqval=f44 */
    0,    /* freqval=f45 */
    0,    /* freqval=f46 */
    0,    /* freqval=f47 */
    0,    /* freqval=f48 */
    0,    /* freqval=f49 */
    0,    /* freqval=f4a */
    0,    /* freqval=f4b */
    0,    /* freqval=f4c */
    0,    /* freqval=f4d */
    0,    /* freqval=f4e */
    0,    /* freqval=f4f */
    0,    /* freqval=f50 */
    0,    /* freqval=f51 */
    0,    /* freqval=f52 */
    0,    /* freqval=f53 */
    0,    /* freqval=f54 */
    0,    /* freqval=f55 */
    0,    /* freqval=f56 */
    0,    /* freqval=f57 */
    0,    /* freqval=f58 */
    0,    /* freqval=f59 */
    0,    /* freqval=f5a */
    0,    /* freqval=f5b */
    0,    /* freqval=f5c */
    0,    /* freqval=f5d */
    0,    /* freqval=f5e */
    0,    /* freqval=f5f */
    0,    /* freqval=f60 */
    0,    /* freqval=f61 */
    0,    /* freqval=f62 */
    0,    /* freqval=f63 */
    0,    /* freqval=f64 */
    0,    /* freqval=f65 */
    0,    /* freqval=f66 */
    0,    /* freqval=f67 */
    0,    /* freqval=f68 */
    0,    /* freqval=f69 */
    0,    /* freqval=f6a */
    0,    /* freqval=f6b */
    0,    /* freqval=f6c */
    0,    /* freqval=f6d */
    0,    /* freqval=f6e */
    0,    /* freqval=f6f */
    0,    /* freqval=f70 */
    0,    /* freqval=f71 */
    0,    /* freqval=f72 */
    0,    /* freqval=f73 */
    0,    /* freqval=f74 */
    0,    /* freqval=f75 */
    0,    /* freqval=f76 */
    0,    /* freqval=f77 */
    0,    /* freqval=f78 */
    0,    /* freqval=f79 */
    0,    /* freqval=f7a */
    0,    /* freqval=f7b */
    0,    /* freqval=f7c */
    0,    /* freqval=f7d */
    0,    /* freqval=f7e */
    0,    /* freqval=f7f */
    0,    /* freqval=f80 */
    0,    /* freqval=f81 */
    0,    /* freqval=f82 */
    0,    /* freqval=f83 */
    0,    /* freqval=f84 */
    0,    /* freqval=f85 */
    0,    /* freqval=f86 */
    0,    /* freqval=f87 */
    0,    /* freqval=f88 */
    0,    /* freqval=f89 */
    0,    /* freqval=f8a */
    0,    /* freqval=f8b */
    0,    /* freqval=f8c */
    0,    /* freqval=f8d */
    0,    /* freqval=f8e */
    0,    /* freqval=f8f */
    0,    /* freqval=f90 */
    0,    /* freqval=f91 */
    0,    /* freqval=f92 */
    0,    /* freqval=f93 */
    0,    /* freqval=f94 */
    0,    /* freqval=f95 */
    0,    /* freqval=f96 */
    0,    /* freqval=f97 */
    0,    /* freqval=f98 */
    0,    /* freqval=f99 */
    0,    /* freqval=f9a */
    0,    /* freqval=f9b */
    0,    /* freqval=f9c */
    0,    /* freqval=f9d */
    0,    /* freqval=f9e */
    0,    /* freqval=f9f */
    0,    /* freqval=fa0 */
    0,    /* freqval=fa1 */
    0,    /* freqval=fa2 */
    0,    /* freqval=fa3 */
    0,    /* freqval=fa4 */
    0,    /* freqval=fa5 */
    0,    /* freqval=fa6 */
    0,    /* freqval=fa7 */
    0,    /* freqval=fa8 */
    0,    /* freqval=fa9 */
    0,    /* freqval=faa */
    0,    /* freqval=fab */
    0,    /* freqval=fac */
    0,    /* freqval=fad */
    0,    /* freqval=fae */
    0,    /* freqval=faf */
    0,    /* freqval=fb0 */
    0,    /* freqval=fb1 */
    0,    /* freqval=fb2 */
    0,    /* freqval=fb3 */
    0,    /* freqval=fb4 */
    0,    /* freqval=fb5 */
    0,    /* freqval=fb6 */
    0,    /* freqval=fb7 */
    0,    /* freqval=fb8 */
    0,    /* freqval=fb9 */
    0,    /* freqval=fba */
    0,    /* freqval=fbb */
    0,    /* freqval=fbc */
    0,    /* freqval=fbd */
    0,    /* freqval=fbe */
    0,    /* freqval=fbf */
    0,    /* freqval=fc0 */
    0,    /* freqval=fc1 */
    0,    /* freqval=fc2 */
    0,    /* freqval=fc3 */
    0,    /* freqval=fc4 */
    0,    /* freqval=fc5 */
    0,    /* freqval=fc6 */
    0,    /* freqval=fc7 */
    0,    /* freqval=fc8 */
    0,    /* freqval=fc9 */
    0,    /* freqval=fca */
    0,    /* freqval=fcb */
    0,    /* freqval=fcc */
    0,    /* freqval=fcd */
    0,    /* freqval=fce */
    0,    /* freqval=fcf */
    0,    /* freqval=fd0 */
    0,    /* freqval=fd1 */
    0,    /* freqval=fd2 */
    0,    /* freqval=fd3 */
    0,    /* freqval=fd4 */
    0,    /* freqval=fd5 */
    0,    /* freqval=fd6 */
    0,    /* freqval=fd7 */
    0,    /* freqval=fd8 */
    0,    /* freqval=fd9 */
    0,    /* freqval=fda */
    0,    /* freqval=fdb */
    0,    /* freqval=fdc */
    0,    /* freqval=fdd */
    0,    /* freqval=fde */
    0,    /* freqval=fdf */
    0,    /* freqval=fe0 */
    0,    /* freqval=fe1 */
    0,    /* freqval=fe2 */
    0,    /* freqval=fe3 */
    0,    /* freqval=fe4 */
    0,    /* freqval=fe5 */
    0,    /* freqval=fe6 */
    0,    /* freqval=fe7 */
    0,    /* freqval=fe8 */
    0,    /* freqval=fe9 */
    0,    /* freqval=fea */
    0,    /* freqval=feb */
    0,    /* freqval=fec */
    0,    /* freqval=fed */
    0,    /* freqval=fee */
    0,    /* freqval=fef */
    0,    /* freqval=ff0 */
    0,    /* freqval=ff1 */
    0,    /* freqval=ff2 */
    0,    /* freqval=ff3 */
    0,    /* freqval=ff4 */
    0,    /* freqval=ff5 */
    0,    /* freqval=ff6 */
    0,    /* freqval=ff7 */
    0,    /* freqval=ff8 */
    0,    /* freqval=ff9 */
    0,    /* freqval=ffa */
    0,    /* freqval=ffb */
    0,    /* freqval=ffc */
    0,    /* freqval=ffd */
    0,    /* freqval=ffe */
    0     /* freqval=fff */
  };

